%%
%% This is file `se-ascii-print.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `ascii-print')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-ascii-print.def}%
  [2019/11/29 v1.12 stringenc: Printable ASCII characters]%
\expandafter\gdef\csname\SE@PrefixTo ascii-print\endcsname#1#2#3#4{%
  \ifnum"#1#2=\ltx@zero
    \ifnum"#3#4<127 %
      \ifnum"#3#4>31 %
        \SE@ResultAdd{#3#4}%
      \else
        \SE@InvalidCharacter
      \fi
    \else
      \SE@InvalidCharacter
    \fi
  \else
    \SE@InvalidCharacter
  \fi
}
\expandafter\gdef\csname\SE@PrefixSurrogateTo ascii-print\endcsname
    #1#2#3#4#5#6#7#8{%
  \SE@InvalidCharacter
}
\expandafter\gdef\csname\SE@PrefixFrom ascii-print\endcsname#1{%
  \let\SE@next\SE@ascii@print@from
  \expandafter\SE@ascii@print@from#1\relax\relax
}
\gdef\SE@ascii@print@from#1#2{%
  \ifx#1\relax
    \let\SE@next\relax
  \else
    \ifnum"#1#2>126 %
      \SE@InvalidCharacter
      \ifSE@TestMode
        \let\SE@next\SE@SkipRemaining
      \fi
    \else
      \ifnum"#1#2<32 %
        \SE@InvalidCharacter
        \ifSE@TestMode
          \let\SE@next\SE@SkipRemaining
        \fi
      \else
        \SE@ResultAdd{00#1#2}%
      \fi
    \fi
  \fi
  \SE@next
}
\endinput
%%
%% End of file `se-ascii-print.def'.
