%%
%% This is file `se-koi8-r.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,koi8-r')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-koi8-r.def}[2019/11/29 v1.12 stringenc: KOI8-R]
\def\SE@this{koi8-r}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{koi8-r}{80}{2500}% BOX DRAWINGS LIGHT HORIZONTAL
\SE@MapDeclare{koi8-r}{81}{2502}% BOX DRAWINGS LIGHT VERTICAL
\SE@MapDeclare{koi8-r}{82}{250C}% BOX DRAWINGS LIGHT DOWN AND RIGHT
\SE@MapDeclare{koi8-r}{83}{2510}% BOX DRAWINGS LIGHT DOWN AND LEFT
\SE@MapDeclare{koi8-r}{84}{2514}% BOX DRAWINGS LIGHT UP AND RIGHT
\SE@MapDeclare{koi8-r}{85}{2518}% BOX DRAWINGS LIGHT UP AND LEFT
\SE@MapDeclare{koi8-r}{86}{251C}% BOX DRAWINGS LIGHT VERTICAL AND RIGHT
\SE@MapDeclare{koi8-r}{87}{2524}% BOX DRAWINGS LIGHT VERTICAL AND LEFT
\SE@MapDeclare{koi8-r}{88}{252C}% BOX DRAWINGS LIGHT DOWN AND HORIZONTAL
\SE@MapDeclare{koi8-r}{89}{2534}% BOX DRAWINGS LIGHT UP AND HORIZONTAL
\SE@MapDeclare{koi8-r}{8A}{253C}% BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL
\SE@MapDeclare{koi8-r}{8B}{2580}% UPPER HALF BLOCK
\SE@MapDeclare{koi8-r}{8C}{2584}% LOWER HALF BLOCK
\SE@MapDeclare{koi8-r}{8D}{2588}% FULL BLOCK
\SE@MapDeclare{koi8-r}{8E}{258C}% LEFT HALF BLOCK
\SE@MapDeclare{koi8-r}{8F}{2590}% RIGHT HALF BLOCK
\SE@MapDeclare{koi8-r}{90}{2591}% LIGHT SHADE
\SE@MapDeclare{koi8-r}{91}{2592}% MEDIUM SHADE
\SE@MapDeclare{koi8-r}{92}{2593}% DARK SHADE
\SE@MapDeclare{koi8-r}{93}{2320}% TOP HALF INTEGRAL
\SE@MapDeclare{koi8-r}{94}{25A0}% BLACK SQUARE
\SE@MapDeclare{koi8-r}{95}{2219}% BULLET OPERATOR
\SE@MapDeclare{koi8-r}{96}{221A}% SQUARE ROOT
\SE@MapDeclare{koi8-r}{97}{2248}% ALMOST EQUAL TO
\SE@MapDeclare{koi8-r}{98}{2264}% LESS-THAN OR EQUAL TO
\SE@MapDeclare{koi8-r}{99}{2265}% GREATER-THAN OR EQUAL TO
\SE@MapDeclare{koi8-r}{9A}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{koi8-r}{9B}{2321}% BOTTOM HALF INTEGRAL
\SE@MapDeclare{koi8-r}{9C}{00B0}% DEGREE SIGN
\SE@MapDeclare{koi8-r}{9D}{00B2}% SUPERSCRIPT TWO
\SE@MapDeclare{koi8-r}{9E}{00B7}% MIDDLE DOT
\SE@MapDeclare{koi8-r}{9F}{00F7}% DIVISION SIGN
\SE@MapDeclare{koi8-r}{A0}{2550}% BOX DRAWINGS DOUBLE HORIZONTAL
\SE@MapDeclare{koi8-r}{A1}{2551}% BOX DRAWINGS DOUBLE VERTICAL
\SE@MapDeclare{koi8-r}{A2}{2552}% BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE
\SE@MapDeclare{koi8-r}{A3}{0451}% CYRILLIC SMALL LETTER IO
\SE@MapDeclare{koi8-r}{A4}{2553}% BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE
\SE@MapDeclare{koi8-r}{A5}{2554}% BOX DRAWINGS DOUBLE DOWN AND RIGHT
\SE@MapDeclare{koi8-r}{A6}{2555}% BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE
\SE@MapDeclare{koi8-r}{A7}{2556}% BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE
\SE@MapDeclare{koi8-r}{A8}{2557}% BOX DRAWINGS DOUBLE DOWN AND LEFT
\SE@MapDeclare{koi8-r}{A9}{2558}% BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE
\SE@MapDeclare{koi8-r}{AA}{2559}% BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE
\SE@MapDeclare{koi8-r}{AB}{255A}% BOX DRAWINGS DOUBLE UP AND RIGHT
\SE@MapDeclare{koi8-r}{AC}{255B}% BOX DRAWINGS UP SINGLE AND LEFT DOUBLE
\SE@MapDeclare{koi8-r}{AD}{255C}% BOX DRAWINGS UP DOUBLE AND LEFT SINGLE
\SE@MapDeclare{koi8-r}{AE}{255D}% BOX DRAWINGS DOUBLE UP AND LEFT
\SE@MapDeclare{koi8-r}{AF}{255E}% BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE
\SE@MapDeclare{koi8-r}{B0}{255F}% BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE
\SE@MapDeclare{koi8-r}{B1}{2560}% BOX DRAWINGS DOUBLE VERTICAL AND RIGHT
\SE@MapDeclare{koi8-r}{B2}{2561}% BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE
\SE@MapDeclare{koi8-r}{B3}{0401}% CYRILLIC CAPITAL LETTER IO
\SE@MapDeclare{koi8-r}{B4}{2562}% BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE
\SE@MapDeclare{koi8-r}{B5}{2563}% BOX DRAWINGS DOUBLE VERTICAL AND LEFT
\SE@MapDeclare{koi8-r}{B6}{2564}% BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE
\SE@MapDeclare{koi8-r}{B7}{2565}% BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE
\SE@MapDeclare{koi8-r}{B8}{2566}% BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL
\SE@MapDeclare{koi8-r}{B9}{2567}% BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE
\SE@MapDeclare{koi8-r}{BA}{2568}% BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE
\SE@MapDeclare{koi8-r}{BB}{2569}% BOX DRAWINGS DOUBLE UP AND HORIZONTAL
\SE@MapDeclare{koi8-r}{BC}{256A}% BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE
\SE@MapDeclare{koi8-r}{BD}{256B}% BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE
\SE@MapDeclare{koi8-r}{BE}{256C}% BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL
\SE@MapDeclare{koi8-r}{BF}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{koi8-r}{C0}{044E}% CYRILLIC SMALL LETTER YU
\SE@MapDeclare{koi8-r}{C1}{0430}% CYRILLIC SMALL LETTER A
\SE@MapDeclare{koi8-r}{C2}{0431}% CYRILLIC SMALL LETTER BE
\SE@MapDeclare{koi8-r}{C3}{0446}% CYRILLIC SMALL LETTER TSE
\SE@MapDeclare{koi8-r}{C4}{0434}% CYRILLIC SMALL LETTER DE
\SE@MapDeclare{koi8-r}{C5}{0435}% CYRILLIC SMALL LETTER IE
\SE@MapDeclare{koi8-r}{C6}{0444}% CYRILLIC SMALL LETTER EF
\SE@MapDeclare{koi8-r}{C7}{0433}% CYRILLIC SMALL LETTER GHE
\SE@MapDeclare{koi8-r}{C8}{0445}% CYRILLIC SMALL LETTER HA
\SE@MapDeclare{koi8-r}{C9}{0438}% CYRILLIC SMALL LETTER I
\SE@MapDeclare{koi8-r}{CA}{0439}% CYRILLIC SMALL LETTER SHORT I
\SE@MapDeclare{koi8-r}{CB}{043A}% CYRILLIC SMALL LETTER KA
\SE@MapDeclare{koi8-r}{CC}{043B}% CYRILLIC SMALL LETTER EL
\SE@MapDeclare{koi8-r}{CD}{043C}% CYRILLIC SMALL LETTER EM
\SE@MapDeclare{koi8-r}{CE}{043D}% CYRILLIC SMALL LETTER EN
\SE@MapDeclare{koi8-r}{CF}{043E}% CYRILLIC SMALL LETTER O
\SE@MapDeclare{koi8-r}{D0}{043F}% CYRILLIC SMALL LETTER PE
\SE@MapDeclare{koi8-r}{D1}{044F}% CYRILLIC SMALL LETTER YA
\SE@MapDeclare{koi8-r}{D2}{0440}% CYRILLIC SMALL LETTER ER
\SE@MapDeclare{koi8-r}{D3}{0441}% CYRILLIC SMALL LETTER ES
\SE@MapDeclare{koi8-r}{D4}{0442}% CYRILLIC SMALL LETTER TE
\SE@MapDeclare{koi8-r}{D5}{0443}% CYRILLIC SMALL LETTER U
\SE@MapDeclare{koi8-r}{D6}{0436}% CYRILLIC SMALL LETTER ZHE
\SE@MapDeclare{koi8-r}{D7}{0432}% CYRILLIC SMALL LETTER VE
\SE@MapDeclare{koi8-r}{D8}{044C}% CYRILLIC SMALL LETTER SOFT SIGN
\SE@MapDeclare{koi8-r}{D9}{044B}% CYRILLIC SMALL LETTER YERU
\SE@MapDeclare{koi8-r}{DA}{0437}% CYRILLIC SMALL LETTER ZE
\SE@MapDeclare{koi8-r}{DB}{0448}% CYRILLIC SMALL LETTER SHA
\SE@MapDeclare{koi8-r}{DC}{044D}% CYRILLIC SMALL LETTER E
\SE@MapDeclare{koi8-r}{DD}{0449}% CYRILLIC SMALL LETTER SHCHA
\SE@MapDeclare{koi8-r}{DE}{0447}% CYRILLIC SMALL LETTER CHE
\SE@MapDeclare{koi8-r}{DF}{044A}% CYRILLIC SMALL LETTER HARD SIGN
\SE@MapDeclare{koi8-r}{E0}{042E}% CYRILLIC CAPITAL LETTER YU
\SE@MapDeclare{koi8-r}{E1}{0410}% CYRILLIC CAPITAL LETTER A
\SE@MapDeclare{koi8-r}{E2}{0411}% CYRILLIC CAPITAL LETTER BE
\SE@MapDeclare{koi8-r}{E3}{0426}% CYRILLIC CAPITAL LETTER TSE
\SE@MapDeclare{koi8-r}{E4}{0414}% CYRILLIC CAPITAL LETTER DE
\SE@MapDeclare{koi8-r}{E5}{0415}% CYRILLIC CAPITAL LETTER IE
\SE@MapDeclare{koi8-r}{E6}{0424}% CYRILLIC CAPITAL LETTER EF
\SE@MapDeclare{koi8-r}{E7}{0413}% CYRILLIC CAPITAL LETTER GHE
\SE@MapDeclare{koi8-r}{E8}{0425}% CYRILLIC CAPITAL LETTER HA
\SE@MapDeclare{koi8-r}{E9}{0418}% CYRILLIC CAPITAL LETTER I
\SE@MapDeclare{koi8-r}{EA}{0419}% CYRILLIC CAPITAL LETTER SHORT I
\SE@MapDeclare{koi8-r}{EB}{041A}% CYRILLIC CAPITAL LETTER KA
\SE@MapDeclare{koi8-r}{EC}{041B}% CYRILLIC CAPITAL LETTER EL
\SE@MapDeclare{koi8-r}{ED}{041C}% CYRILLIC CAPITAL LETTER EM
\SE@MapDeclare{koi8-r}{EE}{041D}% CYRILLIC CAPITAL LETTER EN
\SE@MapDeclare{koi8-r}{EF}{041E}% CYRILLIC CAPITAL LETTER O
\SE@MapDeclare{koi8-r}{F0}{041F}% CYRILLIC CAPITAL LETTER PE
\SE@MapDeclare{koi8-r}{F1}{042F}% CYRILLIC CAPITAL LETTER YA
\SE@MapDeclare{koi8-r}{F2}{0420}% CYRILLIC CAPITAL LETTER ER
\SE@MapDeclare{koi8-r}{F3}{0421}% CYRILLIC CAPITAL LETTER ES
\SE@MapDeclare{koi8-r}{F4}{0422}% CYRILLIC CAPITAL LETTER TE
\SE@MapDeclare{koi8-r}{F5}{0423}% CYRILLIC CAPITAL LETTER U
\SE@MapDeclare{koi8-r}{F6}{0416}% CYRILLIC CAPITAL LETTER ZHE
\SE@MapDeclare{koi8-r}{F7}{0412}% CYRILLIC CAPITAL LETTER VE
\SE@MapDeclare{koi8-r}{F8}{042C}% CYRILLIC CAPITAL LETTER SOFT SIGN
\SE@MapDeclare{koi8-r}{F9}{042B}% CYRILLIC CAPITAL LETTER YERU
\SE@MapDeclare{koi8-r}{FA}{0417}% CYRILLIC CAPITAL LETTER ZE
\SE@MapDeclare{koi8-r}{FB}{0428}% CYRILLIC CAPITAL LETTER SHA
\SE@MapDeclare{koi8-r}{FC}{042D}% CYRILLIC CAPITAL LETTER E
\SE@MapDeclare{koi8-r}{FD}{0429}% CYRILLIC CAPITAL LETTER SHCHA
\SE@MapDeclare{koi8-r}{FE}{0427}% CYRILLIC CAPITAL LETTER CHE
\SE@MapDeclare{koi8-r}{FF}{042A}% CYRILLIC CAPITAL LETTER HARD SIGN
\endinput
%%
%% End of file `se-koi8-r.def'.
