%%
%% This is file `se-iso-8859-5.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,iso-8859-5')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-iso-8859-5.def}[2019/11/29 v1.12 stringenc: ISO-8859-5]
\def\SE@this{iso-8859-5}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{iso-8859-5}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{iso-8859-5}{A1}{0401}% CYRILLIC CAPITAL LETTER IO
\SE@MapDeclare{iso-8859-5}{A2}{0402}% CYRILLIC CAPITAL LETTER DJE
\SE@MapDeclare{iso-8859-5}{A3}{0403}% CYRILLIC CAPITAL LETTER GJE
\SE@MapDeclare{iso-8859-5}{A4}{0404}% CYRILLIC CAPITAL LETTER UKRAINIAN IE
\SE@MapDeclare{iso-8859-5}{A5}{0405}% CYRILLIC CAPITAL LETTER DZE
\SE@MapDeclare{iso-8859-5}{A6}{0406}% CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I
\SE@MapDeclare{iso-8859-5}{A7}{0407}% CYRILLIC CAPITAL LETTER YI
\SE@MapDeclare{iso-8859-5}{A8}{0408}% CYRILLIC CAPITAL LETTER JE
\SE@MapDeclare{iso-8859-5}{A9}{0409}% CYRILLIC CAPITAL LETTER LJE
\SE@MapDeclare{iso-8859-5}{AA}{040A}% CYRILLIC CAPITAL LETTER NJE
\SE@MapDeclare{iso-8859-5}{AB}{040B}% CYRILLIC CAPITAL LETTER TSHE
\SE@MapDeclare{iso-8859-5}{AC}{040C}% CYRILLIC CAPITAL LETTER KJE
\SE@MapDeclare{iso-8859-5}{AD}{00AD}% SOFT HYPHEN
\SE@MapDeclare{iso-8859-5}{AE}{040E}% CYRILLIC CAPITAL LETTER SHORT U
\SE@MapDeclare{iso-8859-5}{AF}{040F}% CYRILLIC CAPITAL LETTER DZHE
\SE@MapDeclare{iso-8859-5}{B0}{0410}% CYRILLIC CAPITAL LETTER A
\SE@MapDeclare{iso-8859-5}{B1}{0411}% CYRILLIC CAPITAL LETTER BE
\SE@MapDeclare{iso-8859-5}{B2}{0412}% CYRILLIC CAPITAL LETTER VE
\SE@MapDeclare{iso-8859-5}{B3}{0413}% CYRILLIC CAPITAL LETTER GHE
\SE@MapDeclare{iso-8859-5}{B4}{0414}% CYRILLIC CAPITAL LETTER DE
\SE@MapDeclare{iso-8859-5}{B5}{0415}% CYRILLIC CAPITAL LETTER IE
\SE@MapDeclare{iso-8859-5}{B6}{0416}% CYRILLIC CAPITAL LETTER ZHE
\SE@MapDeclare{iso-8859-5}{B7}{0417}% CYRILLIC CAPITAL LETTER ZE
\SE@MapDeclare{iso-8859-5}{B8}{0418}% CYRILLIC CAPITAL LETTER I
\SE@MapDeclare{iso-8859-5}{B9}{0419}% CYRILLIC CAPITAL LETTER SHORT I
\SE@MapDeclare{iso-8859-5}{BA}{041A}% CYRILLIC CAPITAL LETTER KA
\SE@MapDeclare{iso-8859-5}{BB}{041B}% CYRILLIC CAPITAL LETTER EL
\SE@MapDeclare{iso-8859-5}{BC}{041C}% CYRILLIC CAPITAL LETTER EM
\SE@MapDeclare{iso-8859-5}{BD}{041D}% CYRILLIC CAPITAL LETTER EN
\SE@MapDeclare{iso-8859-5}{BE}{041E}% CYRILLIC CAPITAL LETTER O
\SE@MapDeclare{iso-8859-5}{BF}{041F}% CYRILLIC CAPITAL LETTER PE
\SE@MapDeclare{iso-8859-5}{C0}{0420}% CYRILLIC CAPITAL LETTER ER
\SE@MapDeclare{iso-8859-5}{C1}{0421}% CYRILLIC CAPITAL LETTER ES
\SE@MapDeclare{iso-8859-5}{C2}{0422}% CYRILLIC CAPITAL LETTER TE
\SE@MapDeclare{iso-8859-5}{C3}{0423}% CYRILLIC CAPITAL LETTER U
\SE@MapDeclare{iso-8859-5}{C4}{0424}% CYRILLIC CAPITAL LETTER EF
\SE@MapDeclare{iso-8859-5}{C5}{0425}% CYRILLIC CAPITAL LETTER HA
\SE@MapDeclare{iso-8859-5}{C6}{0426}% CYRILLIC CAPITAL LETTER TSE
\SE@MapDeclare{iso-8859-5}{C7}{0427}% CYRILLIC CAPITAL LETTER CHE
\SE@MapDeclare{iso-8859-5}{C8}{0428}% CYRILLIC CAPITAL LETTER SHA
\SE@MapDeclare{iso-8859-5}{C9}{0429}% CYRILLIC CAPITAL LETTER SHCHA
\SE@MapDeclare{iso-8859-5}{CA}{042A}% CYRILLIC CAPITAL LETTER HARD SIGN
\SE@MapDeclare{iso-8859-5}{CB}{042B}% CYRILLIC CAPITAL LETTER YERU
\SE@MapDeclare{iso-8859-5}{CC}{042C}% CYRILLIC CAPITAL LETTER SOFT SIGN
\SE@MapDeclare{iso-8859-5}{CD}{042D}% CYRILLIC CAPITAL LETTER E
\SE@MapDeclare{iso-8859-5}{CE}{042E}% CYRILLIC CAPITAL LETTER YU
\SE@MapDeclare{iso-8859-5}{CF}{042F}% CYRILLIC CAPITAL LETTER YA
\SE@MapDeclare{iso-8859-5}{D0}{0430}% CYRILLIC SMALL LETTER A
\SE@MapDeclare{iso-8859-5}{D1}{0431}% CYRILLIC SMALL LETTER BE
\SE@MapDeclare{iso-8859-5}{D2}{0432}% CYRILLIC SMALL LETTER VE
\SE@MapDeclare{iso-8859-5}{D3}{0433}% CYRILLIC SMALL LETTER GHE
\SE@MapDeclare{iso-8859-5}{D4}{0434}% CYRILLIC SMALL LETTER DE
\SE@MapDeclare{iso-8859-5}{D5}{0435}% CYRILLIC SMALL LETTER IE
\SE@MapDeclare{iso-8859-5}{D6}{0436}% CYRILLIC SMALL LETTER ZHE
\SE@MapDeclare{iso-8859-5}{D7}{0437}% CYRILLIC SMALL LETTER ZE
\SE@MapDeclare{iso-8859-5}{D8}{0438}% CYRILLIC SMALL LETTER I
\SE@MapDeclare{iso-8859-5}{D9}{0439}% CYRILLIC SMALL LETTER SHORT I
\SE@MapDeclare{iso-8859-5}{DA}{043A}% CYRILLIC SMALL LETTER KA
\SE@MapDeclare{iso-8859-5}{DB}{043B}% CYRILLIC SMALL LETTER EL
\SE@MapDeclare{iso-8859-5}{DC}{043C}% CYRILLIC SMALL LETTER EM
\SE@MapDeclare{iso-8859-5}{DD}{043D}% CYRILLIC SMALL LETTER EN
\SE@MapDeclare{iso-8859-5}{DE}{043E}% CYRILLIC SMALL LETTER O
\SE@MapDeclare{iso-8859-5}{DF}{043F}% CYRILLIC SMALL LETTER PE
\SE@MapDeclare{iso-8859-5}{E0}{0440}% CYRILLIC SMALL LETTER ER
\SE@MapDeclare{iso-8859-5}{E1}{0441}% CYRILLIC SMALL LETTER ES
\SE@MapDeclare{iso-8859-5}{E2}{0442}% CYRILLIC SMALL LETTER TE
\SE@MapDeclare{iso-8859-5}{E3}{0443}% CYRILLIC SMALL LETTER U
\SE@MapDeclare{iso-8859-5}{E4}{0444}% CYRILLIC SMALL LETTER EF
\SE@MapDeclare{iso-8859-5}{E5}{0445}% CYRILLIC SMALL LETTER HA
\SE@MapDeclare{iso-8859-5}{E6}{0446}% CYRILLIC SMALL LETTER TSE
\SE@MapDeclare{iso-8859-5}{E7}{0447}% CYRILLIC SMALL LETTER CHE
\SE@MapDeclare{iso-8859-5}{E8}{0448}% CYRILLIC SMALL LETTER SHA
\SE@MapDeclare{iso-8859-5}{E9}{0449}% CYRILLIC SMALL LETTER SHCHA
\SE@MapDeclare{iso-8859-5}{EA}{044A}% CYRILLIC SMALL LETTER HARD SIGN
\SE@MapDeclare{iso-8859-5}{EB}{044B}% CYRILLIC SMALL LETTER YERU
\SE@MapDeclare{iso-8859-5}{EC}{044C}% CYRILLIC SMALL LETTER SOFT SIGN
\SE@MapDeclare{iso-8859-5}{ED}{044D}% CYRILLIC SMALL LETTER E
\SE@MapDeclare{iso-8859-5}{EE}{044E}% CYRILLIC SMALL LETTER YU
\SE@MapDeclare{iso-8859-5}{EF}{044F}% CYRILLIC SMALL LETTER YA
\SE@MapDeclare{iso-8859-5}{F0}{2116}% NUMERO SIGN
\SE@MapDeclare{iso-8859-5}{F1}{0451}% CYRILLIC SMALL LETTER IO
\SE@MapDeclare{iso-8859-5}{F2}{0452}% CYRILLIC SMALL LETTER DJE
\SE@MapDeclare{iso-8859-5}{F3}{0453}% CYRILLIC SMALL LETTER GJE
\SE@MapDeclare{iso-8859-5}{F4}{0454}% CYRILLIC SMALL LETTER UKRAINIAN IE
\SE@MapDeclare{iso-8859-5}{F5}{0455}% CYRILLIC SMALL LETTER DZE
\SE@MapDeclare{iso-8859-5}{F6}{0456}% CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I
\SE@MapDeclare{iso-8859-5}{F7}{0457}% CYRILLIC SMALL LETTER YI
\SE@MapDeclare{iso-8859-5}{F8}{0458}% CYRILLIC SMALL LETTER JE
\SE@MapDeclare{iso-8859-5}{F9}{0459}% CYRILLIC SMALL LETTER LJE
\SE@MapDeclare{iso-8859-5}{FA}{045A}% CYRILLIC SMALL LETTER NJE
\SE@MapDeclare{iso-8859-5}{FB}{045B}% CYRILLIC SMALL LETTER TSHE
\SE@MapDeclare{iso-8859-5}{FC}{045C}% CYRILLIC SMALL LETTER KJE
\SE@MapDeclare{iso-8859-5}{FD}{00A7}% SECTION SIGN
\SE@MapDeclare{iso-8859-5}{FE}{045E}% CYRILLIC SMALL LETTER SHORT U
\SE@MapDeclare{iso-8859-5}{FF}{045F}% CYRILLIC SMALL LETTER DZHE
\endinput
%%
%% End of file `se-iso-8859-5.def'.
