%%
%% This is file `se-cp865.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,cp865')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-cp865.def}[2019/11/29 v1.12 stringenc: cp865]
\def\SE@this{cp865}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{cp865}{80}{00C7}% LATIN CAPITAL LETTER C WITH CEDILLA
\SE@MapDeclare{cp865}{81}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp865}{82}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{cp865}{83}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{cp865}{84}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp865}{85}{00E0}% LATIN SMALL LETTER A WITH GRAVE
\SE@MapDeclare{cp865}{86}{00E5}% LATIN SMALL LETTER A WITH RING ABOVE
\SE@MapDeclare{cp865}{87}{00E7}% LATIN SMALL LETTER C WITH CEDILLA
\SE@MapDeclare{cp865}{88}{00EA}% LATIN SMALL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{cp865}{89}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{cp865}{8A}{00E8}% LATIN SMALL LETTER E WITH GRAVE
\SE@MapDeclare{cp865}{8B}{00EF}% LATIN SMALL LETTER I WITH DIAERESIS
\SE@MapDeclare{cp865}{8C}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{cp865}{8D}{00EC}% LATIN SMALL LETTER I WITH GRAVE
\SE@MapDeclare{cp865}{8E}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp865}{8F}{00C5}% LATIN CAPITAL LETTER A WITH RING ABOVE
\SE@MapDeclare{cp865}{90}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{cp865}{91}{00E6}% LATIN SMALL LIGATURE AE
\SE@MapDeclare{cp865}{92}{00C6}% LATIN CAPITAL LIGATURE AE
\SE@MapDeclare{cp865}{93}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{cp865}{94}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp865}{95}{00F2}% LATIN SMALL LETTER O WITH GRAVE
\SE@MapDeclare{cp865}{96}{00FB}% LATIN SMALL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{cp865}{97}{00F9}% LATIN SMALL LETTER U WITH GRAVE
\SE@MapDeclare{cp865}{98}{00FF}% LATIN SMALL LETTER Y WITH DIAERESIS
\SE@MapDeclare{cp865}{99}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp865}{9A}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp865}{9B}{00F8}% LATIN SMALL LETTER O WITH STROKE
\SE@MapDeclare{cp865}{9C}{00A3}% POUND SIGN
\SE@MapDeclare{cp865}{9D}{00D8}% LATIN CAPITAL LETTER O WITH STROKE
\SE@MapDeclare{cp865}{9E}{20A7}% PESETA SIGN
\SE@MapDeclare{cp865}{9F}{0192}% LATIN SMALL LETTER F WITH HOOK
\SE@MapDeclare{cp865}{A0}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{cp865}{A1}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{cp865}{A2}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{cp865}{A3}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{cp865}{A4}{00F1}% LATIN SMALL LETTER N WITH TILDE
\SE@MapDeclare{cp865}{A5}{00D1}% LATIN CAPITAL LETTER N WITH TILDE
\SE@MapDeclare{cp865}{A6}{00AA}% FEMININE ORDINAL INDICATOR
\SE@MapDeclare{cp865}{A7}{00BA}% MASCULINE ORDINAL INDICATOR
\SE@MapDeclare{cp865}{A8}{00BF}% INVERTED QUESTION MARK
\SE@MapDeclare{cp865}{A9}{2310}% REVERSED NOT SIGN
\SE@MapDeclare{cp865}{AA}{00AC}% NOT SIGN
\SE@MapDeclare{cp865}{AB}{00BD}% VULGAR FRACTION ONE HALF
\SE@MapDeclare{cp865}{AC}{00BC}% VULGAR FRACTION ONE QUARTER
\SE@MapDeclare{cp865}{AD}{00A1}% INVERTED EXCLAMATION MARK
\SE@MapDeclare{cp865}{AE}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{cp865}{AF}{00A4}% CURRENCY SIGN
\SE@MapDeclare{cp865}{B0}{2591}% LIGHT SHADE
\SE@MapDeclare{cp865}{B1}{2592}% MEDIUM SHADE
\SE@MapDeclare{cp865}{B2}{2593}% DARK SHADE
\SE@MapDeclare{cp865}{B3}{2502}% BOX DRAWINGS LIGHT VERTICAL
\SE@MapDeclare{cp865}{B4}{2524}% BOX DRAWINGS LIGHT VERTICAL AND LEFT
\SE@MapDeclare{cp865}{B5}{2561}% BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE
\SE@MapDeclare{cp865}{B6}{2562}% BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE
\SE@MapDeclare{cp865}{B7}{2556}% BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE
\SE@MapDeclare{cp865}{B8}{2555}% BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE
\SE@MapDeclare{cp865}{B9}{2563}% BOX DRAWINGS DOUBLE VERTICAL AND LEFT
\SE@MapDeclare{cp865}{BA}{2551}% BOX DRAWINGS DOUBLE VERTICAL
\SE@MapDeclare{cp865}{BB}{2557}% BOX DRAWINGS DOUBLE DOWN AND LEFT
\SE@MapDeclare{cp865}{BC}{255D}% BOX DRAWINGS DOUBLE UP AND LEFT
\SE@MapDeclare{cp865}{BD}{255C}% BOX DRAWINGS UP DOUBLE AND LEFT SINGLE
\SE@MapDeclare{cp865}{BE}{255B}% BOX DRAWINGS UP SINGLE AND LEFT DOUBLE
\SE@MapDeclare{cp865}{BF}{2510}% BOX DRAWINGS LIGHT DOWN AND LEFT
\SE@MapDeclare{cp865}{C0}{2514}% BOX DRAWINGS LIGHT UP AND RIGHT
\SE@MapDeclare{cp865}{C1}{2534}% BOX DRAWINGS LIGHT UP AND HORIZONTAL
\SE@MapDeclare{cp865}{C2}{252C}% BOX DRAWINGS LIGHT DOWN AND HORIZONTAL
\SE@MapDeclare{cp865}{C3}{251C}% BOX DRAWINGS LIGHT VERTICAL AND RIGHT
\SE@MapDeclare{cp865}{C4}{2500}% BOX DRAWINGS LIGHT HORIZONTAL
\SE@MapDeclare{cp865}{C5}{253C}% BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL
\SE@MapDeclare{cp865}{C6}{255E}% BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE
\SE@MapDeclare{cp865}{C7}{255F}% BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE
\SE@MapDeclare{cp865}{C8}{255A}% BOX DRAWINGS DOUBLE UP AND RIGHT
\SE@MapDeclare{cp865}{C9}{2554}% BOX DRAWINGS DOUBLE DOWN AND RIGHT
\SE@MapDeclare{cp865}{CA}{2569}% BOX DRAWINGS DOUBLE UP AND HORIZONTAL
\SE@MapDeclare{cp865}{CB}{2566}% BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL
\SE@MapDeclare{cp865}{CC}{2560}% BOX DRAWINGS DOUBLE VERTICAL AND RIGHT
\SE@MapDeclare{cp865}{CD}{2550}% BOX DRAWINGS DOUBLE HORIZONTAL
\SE@MapDeclare{cp865}{CE}{256C}% BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL
\SE@MapDeclare{cp865}{CF}{2567}% BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE
\SE@MapDeclare{cp865}{D0}{2568}% BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE
\SE@MapDeclare{cp865}{D1}{2564}% BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE
\SE@MapDeclare{cp865}{D2}{2565}% BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE
\SE@MapDeclare{cp865}{D3}{2559}% BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE
\SE@MapDeclare{cp865}{D4}{2558}% BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE
\SE@MapDeclare{cp865}{D5}{2552}% BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE
\SE@MapDeclare{cp865}{D6}{2553}% BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE
\SE@MapDeclare{cp865}{D7}{256B}% BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE
\SE@MapDeclare{cp865}{D8}{256A}% BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE
\SE@MapDeclare{cp865}{D9}{2518}% BOX DRAWINGS LIGHT UP AND LEFT
\SE@MapDeclare{cp865}{DA}{250C}% BOX DRAWINGS LIGHT DOWN AND RIGHT
\SE@MapDeclare{cp865}{DB}{2588}% FULL BLOCK
\SE@MapDeclare{cp865}{DC}{2584}% LOWER HALF BLOCK
\SE@MapDeclare{cp865}{DD}{258C}% LEFT HALF BLOCK
\SE@MapDeclare{cp865}{DE}{2590}% RIGHT HALF BLOCK
\SE@MapDeclare{cp865}{DF}{2580}% UPPER HALF BLOCK
\SE@MapDeclare{cp865}{E0}{03B1}% GREEK SMALL LETTER ALPHA
\SE@MapDeclare{cp865}{E1}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{cp865}{E2}{0393}% GREEK CAPITAL LETTER GAMMA
\SE@MapDeclare{cp865}{E3}{03C0}% GREEK SMALL LETTER PI
\SE@MapDeclare{cp865}{E4}{03A3}% GREEK CAPITAL LETTER SIGMA
\SE@MapDeclare{cp865}{E5}{03C3}% GREEK SMALL LETTER SIGMA
\SE@MapDeclare{cp865}{E6}{00B5}% MICRO SIGN
\SE@MapDeclare{cp865}{E7}{03C4}% GREEK SMALL LETTER TAU
\SE@MapDeclare{cp865}{E8}{03A6}% GREEK CAPITAL LETTER PHI
\SE@MapDeclare{cp865}{E9}{0398}% GREEK CAPITAL LETTER THETA
\SE@MapDeclare{cp865}{EA}{03A9}% GREEK CAPITAL LETTER OMEGA
\SE@MapDeclare{cp865}{EB}{03B4}% GREEK SMALL LETTER DELTA
\SE@MapDeclare{cp865}{EC}{221E}% INFINITY
\SE@MapDeclare{cp865}{ED}{03C6}% GREEK SMALL LETTER PHI
\SE@MapDeclare{cp865}{EE}{03B5}% GREEK SMALL LETTER EPSILON
\SE@MapDeclare{cp865}{EF}{2229}% INTERSECTION
\SE@MapDeclare{cp865}{F0}{2261}% IDENTICAL TO
\SE@MapDeclare{cp865}{F1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{cp865}{F2}{2265}% GREATER-THAN OR EQUAL TO
\SE@MapDeclare{cp865}{F3}{2264}% LESS-THAN OR EQUAL TO
\SE@MapDeclare{cp865}{F4}{2320}% TOP HALF INTEGRAL
\SE@MapDeclare{cp865}{F5}{2321}% BOTTOM HALF INTEGRAL
\SE@MapDeclare{cp865}{F6}{00F7}% DIVISION SIGN
\SE@MapDeclare{cp865}{F7}{2248}% ALMOST EQUAL TO
\SE@MapDeclare{cp865}{F8}{00B0}% DEGREE SIGN
\SE@MapDeclare{cp865}{F9}{2219}% BULLET OPERATOR
\SE@MapDeclare{cp865}{FA}{00B7}% MIDDLE DOT
\SE@MapDeclare{cp865}{FB}{221A}% SQUARE ROOT
\SE@MapDeclare{cp865}{FC}{207F}% SUPERSCRIPT LATIN SMALL LETTER N
\SE@MapDeclare{cp865}{FD}{00B2}% SUPERSCRIPT TWO
\SE@MapDeclare{cp865}{FE}{25A0}% BLACK SQUARE
\SE@MapDeclare{cp865}{FF}{00A0}% NO-BREAK SPACE
\endinput
%%
%% End of file `se-cp865.def'.
