%%
%% This is file `se-dec-mcs.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,dec-mcs')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-dec-mcs.def}[2019/11/29 v1.12 stringenc: DEC-MCS]
\def\SE@this{dec-mcs}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{dec-mcs}{A1}{00A1}% INVERTED EXCLAMATION MARK
\SE@MapDeclare{dec-mcs}{A2}{00A2}% CENT SIGN
\SE@MapDeclare{dec-mcs}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{dec-mcs}{A5}{00A5}% YEN SIGN
\SE@MapDeclare{dec-mcs}{A7}{00A7}% SECTION SIGN
\SE@MapDeclare{dec-mcs}{A8}{00A4}% CURRENCY SIGN
\SE@MapDeclare{dec-mcs}{A9}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{dec-mcs}{AA}{00AA}% FEMININE ORDINAL INDICATOR
\SE@MapDeclare{dec-mcs}{AB}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{dec-mcs}{B0}{00B0}% DEGREE SIGN
\SE@MapDeclare{dec-mcs}{B1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{dec-mcs}{B2}{00B2}% SUPERSCRIPT TWO
\SE@MapDeclare{dec-mcs}{B3}{00B3}% SUPERSCRIPT THREE
\SE@MapDeclare{dec-mcs}{B5}{00B5}% MICRO SIGN
\SE@MapDeclare{dec-mcs}{B6}{00B6}% PILCROW SIGN
\SE@MapDeclare{dec-mcs}{B7}{00B7}% MIDDLE DOT
\SE@MapDeclare{dec-mcs}{B9}{00B9}% SUPERSCRIPT ONE
\SE@MapDeclare{dec-mcs}{BA}{00BA}% MASCULINE ORDINAL INDICATOR
\SE@MapDeclare{dec-mcs}{BB}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{dec-mcs}{BC}{00BC}% VULGAR FRACTION ONE QUARTER
\SE@MapDeclare{dec-mcs}{BD}{00BD}% VULGAR FRACTION ONE HALF
\SE@MapDeclare{dec-mcs}{BF}{00BF}% INVERTED QUESTION MARK
\SE@MapDeclare{dec-mcs}{C0}{00C0}% LATIN CAPITAL LETTER A WITH GRAVE
\SE@MapDeclare{dec-mcs}{C1}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{dec-mcs}{C2}{00C2}% LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{C3}{00C3}% LATIN CAPITAL LETTER A WITH TILDE
\SE@MapDeclare{dec-mcs}{C4}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{C5}{00C5}% LATIN CAPITAL LETTER A WITH RING ABOVE
\SE@MapDeclare{dec-mcs}{C6}{00C6}% LATIN CAPITAL LETTER AE
\SE@MapDeclare{dec-mcs}{C7}{00C7}% LATIN CAPITAL LETTER C WITH CEDILLA
\SE@MapDeclare{dec-mcs}{C8}{00C8}% LATIN CAPITAL LETTER E WITH GRAVE
\SE@MapDeclare{dec-mcs}{C9}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{dec-mcs}{CA}{00CA}% LATIN CAPITAL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{CB}{00CB}% LATIN CAPITAL LETTER E WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{CC}{00CC}% LATIN CAPITAL LETTER I WITH GRAVE
\SE@MapDeclare{dec-mcs}{CD}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{dec-mcs}{CE}{00CE}% LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{CF}{00CF}% LATIN CAPITAL LETTER I WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{D1}{00D1}% LATIN CAPITAL LETTER N WITH TILDE
\SE@MapDeclare{dec-mcs}{D2}{00D2}% LATIN CAPITAL LETTER O WITH GRAVE
\SE@MapDeclare{dec-mcs}{D3}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{dec-mcs}{D4}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{D5}{00D5}% LATIN CAPITAL LETTER O WITH TILDE
\SE@MapDeclare{dec-mcs}{D6}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{D7}{0152}% LATIN CAPITAL LIGATURE OE
\SE@MapDeclare{dec-mcs}{D8}{00D8}% LATIN CAPITAL LETTER O WITH STROKE
\SE@MapDeclare{dec-mcs}{D9}{00D9}% LATIN CAPITAL LETTER U WITH GRAVE
\SE@MapDeclare{dec-mcs}{DA}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{dec-mcs}{DB}{00DB}% LATIN CAPITAL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{DC}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{DD}{0178}% LATIN CAPITAL LETTER Y WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{DF}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{dec-mcs}{E0}{00E0}% LATIN SMALL LETTER A WITH GRAVE
\SE@MapDeclare{dec-mcs}{E1}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{dec-mcs}{E2}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{E3}{00E3}% LATIN SMALL LETTER A WITH TILDE
\SE@MapDeclare{dec-mcs}{E4}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{E5}{00E5}% LATIN SMALL LETTER A WITH RING ABOVE
\SE@MapDeclare{dec-mcs}{E6}{00E6}% LATIN SMALL LETTER AE
\SE@MapDeclare{dec-mcs}{E7}{00E7}% LATIN SMALL LETTER C WITH CEDILLA
\SE@MapDeclare{dec-mcs}{E8}{00E8}% LATIN SMALL LETTER E WITH GRAVE
\SE@MapDeclare{dec-mcs}{E9}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{dec-mcs}{EA}{00EA}% LATIN SMALL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{EB}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{EC}{00EC}% LATIN SMALL LETTER I WITH GRAVE
\SE@MapDeclare{dec-mcs}{ED}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{dec-mcs}{EE}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{EF}{00EF}% LATIN SMALL LETTER I WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{F1}{00F1}% LATIN SMALL LETTER N WITH TILDE
\SE@MapDeclare{dec-mcs}{F2}{00F2}% LATIN SMALL LETTER O WITH GRAVE
\SE@MapDeclare{dec-mcs}{F3}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{dec-mcs}{F4}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{F5}{00F5}% LATIN SMALL LETTER O WITH TILDE
\SE@MapDeclare{dec-mcs}{F6}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{F7}{0153}% LATIN SMALL LIGATURE OE
\SE@MapDeclare{dec-mcs}{F8}{00F8}% LATIN SMALL LETTER O WITH STROKE
\SE@MapDeclare{dec-mcs}{F9}{00F9}% LATIN SMALL LETTER U WITH GRAVE
\SE@MapDeclare{dec-mcs}{FA}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{dec-mcs}{FB}{00FB}% LATIN SMALL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{dec-mcs}{FC}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{dec-mcs}{FD}{00FF}% LATIN SMALL LETTER Y WITH DIAERESIS
\endinput
%%
%% End of file `se-dec-mcs.def'.
