%%
%% This is file `se-cp1250.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,cp1250')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-cp1250.def}[2019/11/29 v1.12 stringenc: cp1250]
\def\SE@this{cp1250}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{cp1250}{80}{20AC}% EURO SIGN
\SE@MapDeclare{cp1250}{82}{201A}% SINGLE LOW-9 QUOTATION MARK
\SE@MapDeclare{cp1250}{84}{201E}% DOUBLE LOW-9 QUOTATION MARK
\SE@MapDeclare{cp1250}{85}{2026}% HORIZONTAL ELLIPSIS
\SE@MapDeclare{cp1250}{86}{2020}% DAGGER
\SE@MapDeclare{cp1250}{87}{2021}% DOUBLE DAGGER
\SE@MapDeclare{cp1250}{89}{2030}% PER MILLE SIGN
\SE@MapDeclare{cp1250}{8A}{0160}% LATIN CAPITAL LETTER S WITH CARON
\SE@MapDeclare{cp1250}{8B}{2039}% SINGLE LEFT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{cp1250}{8C}{015A}% LATIN CAPITAL LETTER S WITH ACUTE
\SE@MapDeclare{cp1250}{8D}{0164}% LATIN CAPITAL LETTER T WITH CARON
\SE@MapDeclare{cp1250}{8E}{017D}% LATIN CAPITAL LETTER Z WITH CARON
\SE@MapDeclare{cp1250}{8F}{0179}% LATIN CAPITAL LETTER Z WITH ACUTE
\SE@MapDeclare{cp1250}{91}{2018}% LEFT SINGLE QUOTATION MARK
\SE@MapDeclare{cp1250}{92}{2019}% RIGHT SINGLE QUOTATION MARK
\SE@MapDeclare{cp1250}{93}{201C}% LEFT DOUBLE QUOTATION MARK
\SE@MapDeclare{cp1250}{94}{201D}% RIGHT DOUBLE QUOTATION MARK
\SE@MapDeclare{cp1250}{95}{2022}% BULLET
\SE@MapDeclare{cp1250}{96}{2013}% EN DASH
\SE@MapDeclare{cp1250}{97}{2014}% EM DASH
\SE@MapDeclare{cp1250}{99}{2122}% TRADE MARK SIGN
\SE@MapDeclare{cp1250}{9A}{0161}% LATIN SMALL LETTER S WITH CARON
\SE@MapDeclare{cp1250}{9B}{203A}% SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{cp1250}{9C}{015B}% LATIN SMALL LETTER S WITH ACUTE
\SE@MapDeclare{cp1250}{9D}{0165}% LATIN SMALL LETTER T WITH CARON
\SE@MapDeclare{cp1250}{9E}{017E}% LATIN SMALL LETTER Z WITH CARON
\SE@MapDeclare{cp1250}{9F}{017A}% LATIN SMALL LETTER Z WITH ACUTE
\SE@MapDeclare{cp1250}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{cp1250}{A1}{02C7}% CARON
\SE@MapDeclare{cp1250}{A2}{02D8}% BREVE
\SE@MapDeclare{cp1250}{A3}{0141}% LATIN CAPITAL LETTER L WITH STROKE
\SE@MapDeclare{cp1250}{A4}{00A4}% CURRENCY SIGN
\SE@MapDeclare{cp1250}{A5}{0104}% LATIN CAPITAL LETTER A WITH OGONEK
\SE@MapDeclare{cp1250}{A6}{00A6}% BROKEN BAR
\SE@MapDeclare{cp1250}{A7}{00A7}% SECTION SIGN
\SE@MapDeclare{cp1250}{A8}{00A8}% DIAERESIS
\SE@MapDeclare{cp1250}{A9}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{cp1250}{AA}{015E}% LATIN CAPITAL LETTER S WITH CEDILLA
\SE@MapDeclare{cp1250}{AB}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{cp1250}{AC}{00AC}% NOT SIGN
\SE@MapDeclare{cp1250}{AD}{00AD}% SOFT HYPHEN
\SE@MapDeclare{cp1250}{AE}{00AE}% REGISTERED SIGN
\SE@MapDeclare{cp1250}{AF}{017B}% LATIN CAPITAL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{cp1250}{B0}{00B0}% DEGREE SIGN
\SE@MapDeclare{cp1250}{B1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{cp1250}{B2}{02DB}% OGONEK
\SE@MapDeclare{cp1250}{B3}{0142}% LATIN SMALL LETTER L WITH STROKE
\SE@MapDeclare{cp1250}{B4}{00B4}% ACUTE ACCENT
\SE@MapDeclare{cp1250}{B5}{00B5}% MICRO SIGN
\SE@MapDeclare{cp1250}{B6}{00B6}% PILCROW SIGN
\SE@MapDeclare{cp1250}{B7}{00B7}% MIDDLE DOT
\SE@MapDeclare{cp1250}{B8}{00B8}% CEDILLA
\SE@MapDeclare{cp1250}{B9}{0105}% LATIN SMALL LETTER A WITH OGONEK
\SE@MapDeclare{cp1250}{BA}{015F}% LATIN SMALL LETTER S WITH CEDILLA
\SE@MapDeclare{cp1250}{BB}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{cp1250}{BC}{013D}% LATIN CAPITAL LETTER L WITH CARON
\SE@MapDeclare{cp1250}{BD}{02DD}% DOUBLE ACUTE ACCENT
\SE@MapDeclare{cp1250}{BE}{013E}% LATIN SMALL LETTER L WITH CARON
\SE@MapDeclare{cp1250}{BF}{017C}% LATIN SMALL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{cp1250}{C0}{0154}% LATIN CAPITAL LETTER R WITH ACUTE
\SE@MapDeclare{cp1250}{C1}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{cp1250}{C2}{00C2}% LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{cp1250}{C3}{0102}% LATIN CAPITAL LETTER A WITH BREVE
\SE@MapDeclare{cp1250}{C4}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp1250}{C5}{0139}% LATIN CAPITAL LETTER L WITH ACUTE
\SE@MapDeclare{cp1250}{C6}{0106}% LATIN CAPITAL LETTER C WITH ACUTE
\SE@MapDeclare{cp1250}{C7}{00C7}% LATIN CAPITAL LETTER C WITH CEDILLA
\SE@MapDeclare{cp1250}{C8}{010C}% LATIN CAPITAL LETTER C WITH CARON
\SE@MapDeclare{cp1250}{C9}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{cp1250}{CA}{0118}% LATIN CAPITAL LETTER E WITH OGONEK
\SE@MapDeclare{cp1250}{CB}{00CB}% LATIN CAPITAL LETTER E WITH DIAERESIS
\SE@MapDeclare{cp1250}{CC}{011A}% LATIN CAPITAL LETTER E WITH CARON
\SE@MapDeclare{cp1250}{CD}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{cp1250}{CE}{00CE}% LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{cp1250}{CF}{010E}% LATIN CAPITAL LETTER D WITH CARON
\SE@MapDeclare{cp1250}{D0}{0110}% LATIN CAPITAL LETTER D WITH STROKE
\SE@MapDeclare{cp1250}{D1}{0143}% LATIN CAPITAL LETTER N WITH ACUTE
\SE@MapDeclare{cp1250}{D2}{0147}% LATIN CAPITAL LETTER N WITH CARON
\SE@MapDeclare{cp1250}{D3}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{cp1250}{D4}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{cp1250}{D5}{0150}% LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
\SE@MapDeclare{cp1250}{D6}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp1250}{D7}{00D7}% MULTIPLICATION SIGN
\SE@MapDeclare{cp1250}{D8}{0158}% LATIN CAPITAL LETTER R WITH CARON
\SE@MapDeclare{cp1250}{D9}{016E}% LATIN CAPITAL LETTER U WITH RING ABOVE
\SE@MapDeclare{cp1250}{DA}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{cp1250}{DB}{0170}% LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
\SE@MapDeclare{cp1250}{DC}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp1250}{DD}{00DD}% LATIN CAPITAL LETTER Y WITH ACUTE
\SE@MapDeclare{cp1250}{DE}{0162}% LATIN CAPITAL LETTER T WITH CEDILLA
\SE@MapDeclare{cp1250}{DF}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{cp1250}{E0}{0155}% LATIN SMALL LETTER R WITH ACUTE
\SE@MapDeclare{cp1250}{E1}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{cp1250}{E2}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{cp1250}{E3}{0103}% LATIN SMALL LETTER A WITH BREVE
\SE@MapDeclare{cp1250}{E4}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp1250}{E5}{013A}% LATIN SMALL LETTER L WITH ACUTE
\SE@MapDeclare{cp1250}{E6}{0107}% LATIN SMALL LETTER C WITH ACUTE
\SE@MapDeclare{cp1250}{E7}{00E7}% LATIN SMALL LETTER C WITH CEDILLA
\SE@MapDeclare{cp1250}{E8}{010D}% LATIN SMALL LETTER C WITH CARON
\SE@MapDeclare{cp1250}{E9}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{cp1250}{EA}{0119}% LATIN SMALL LETTER E WITH OGONEK
\SE@MapDeclare{cp1250}{EB}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{cp1250}{EC}{011B}% LATIN SMALL LETTER E WITH CARON
\SE@MapDeclare{cp1250}{ED}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{cp1250}{EE}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{cp1250}{EF}{010F}% LATIN SMALL LETTER D WITH CARON
\SE@MapDeclare{cp1250}{F0}{0111}% LATIN SMALL LETTER D WITH STROKE
\SE@MapDeclare{cp1250}{F1}{0144}% LATIN SMALL LETTER N WITH ACUTE
\SE@MapDeclare{cp1250}{F2}{0148}% LATIN SMALL LETTER N WITH CARON
\SE@MapDeclare{cp1250}{F3}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{cp1250}{F4}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{cp1250}{F5}{0151}% LATIN SMALL LETTER O WITH DOUBLE ACUTE
\SE@MapDeclare{cp1250}{F6}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp1250}{F7}{00F7}% DIVISION SIGN
\SE@MapDeclare{cp1250}{F8}{0159}% LATIN SMALL LETTER R WITH CARON
\SE@MapDeclare{cp1250}{F9}{016F}% LATIN SMALL LETTER U WITH RING ABOVE
\SE@MapDeclare{cp1250}{FA}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{cp1250}{FB}{0171}% LATIN SMALL LETTER U WITH DOUBLE ACUTE
\SE@MapDeclare{cp1250}{FC}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp1250}{FD}{00FD}% LATIN SMALL LETTER Y WITH ACUTE
\SE@MapDeclare{cp1250}{FE}{0163}% LATIN SMALL LETTER T WITH CEDILLA
\SE@MapDeclare{cp1250}{FF}{02D9}% DOT ABOVE
\endinput
%%
%% End of file `se-cp1250.def'.
