%%
%% This is file `se-iso-8859-6.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,iso-8859-6')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-iso-8859-6.def}[2019/11/29 v1.12 stringenc: ISO-8859-6]
\def\SE@this{iso-8859-6}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{iso-8859-6}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{iso-8859-6}{A4}{00A4}% CURRENCY SIGN
\SE@MapDeclare{iso-8859-6}{AC}{060C}% ARABIC COMMA
\SE@MapDeclare{iso-8859-6}{AD}{00AD}% SOFT HYPHEN
\SE@MapDeclare{iso-8859-6}{BB}{061B}% ARABIC SEMICOLON
\SE@MapDeclare{iso-8859-6}{BF}{061F}% ARABIC QUESTION MARK
\SE@MapDeclare{iso-8859-6}{C1}{0621}% ARABIC LETTER HAMZA
\SE@MapDeclare{iso-8859-6}{C2}{0622}% ARABIC LETTER ALEF WITH MADDA ABOVE
\SE@MapDeclare{iso-8859-6}{C3}{0623}% ARABIC LETTER ALEF WITH HAMZA ABOVE
\SE@MapDeclare{iso-8859-6}{C4}{0624}% ARABIC LETTER WAW WITH HAMZA ABOVE
\SE@MapDeclare{iso-8859-6}{C5}{0625}% ARABIC LETTER ALEF WITH HAMZA BELOW
\SE@MapDeclare{iso-8859-6}{C6}{0626}% ARABIC LETTER YEH WITH HAMZA ABOVE
\SE@MapDeclare{iso-8859-6}{C7}{0627}% ARABIC LETTER ALEF
\SE@MapDeclare{iso-8859-6}{C8}{0628}% ARABIC LETTER BEH
\SE@MapDeclare{iso-8859-6}{C9}{0629}% ARABIC LETTER TEH MARBUTA
\SE@MapDeclare{iso-8859-6}{CA}{062A}% ARABIC LETTER TEH
\SE@MapDeclare{iso-8859-6}{CB}{062B}% ARABIC LETTER THEH
\SE@MapDeclare{iso-8859-6}{CC}{062C}% ARABIC LETTER JEEM
\SE@MapDeclare{iso-8859-6}{CD}{062D}% ARABIC LETTER HAH
\SE@MapDeclare{iso-8859-6}{CE}{062E}% ARABIC LETTER KHAH
\SE@MapDeclare{iso-8859-6}{CF}{062F}% ARABIC LETTER DAL
\SE@MapDeclare{iso-8859-6}{D0}{0630}% ARABIC LETTER THAL
\SE@MapDeclare{iso-8859-6}{D1}{0631}% ARABIC LETTER REH
\SE@MapDeclare{iso-8859-6}{D2}{0632}% ARABIC LETTER ZAIN
\SE@MapDeclare{iso-8859-6}{D3}{0633}% ARABIC LETTER SEEN
\SE@MapDeclare{iso-8859-6}{D4}{0634}% ARABIC LETTER SHEEN
\SE@MapDeclare{iso-8859-6}{D5}{0635}% ARABIC LETTER SAD
\SE@MapDeclare{iso-8859-6}{D6}{0636}% ARABIC LETTER DAD
\SE@MapDeclare{iso-8859-6}{D7}{0637}% ARABIC LETTER TAH
\SE@MapDeclare{iso-8859-6}{D8}{0638}% ARABIC LETTER ZAH
\SE@MapDeclare{iso-8859-6}{D9}{0639}% ARABIC LETTER AIN
\SE@MapDeclare{iso-8859-6}{DA}{063A}% ARABIC LETTER GHAIN
\SE@MapDeclare{iso-8859-6}{E0}{0640}% ARABIC TATWEEL
\SE@MapDeclare{iso-8859-6}{E1}{0641}% ARABIC LETTER FEH
\SE@MapDeclare{iso-8859-6}{E2}{0642}% ARABIC LETTER QAF
\SE@MapDeclare{iso-8859-6}{E3}{0643}% ARABIC LETTER KAF
\SE@MapDeclare{iso-8859-6}{E4}{0644}% ARABIC LETTER LAM
\SE@MapDeclare{iso-8859-6}{E5}{0645}% ARABIC LETTER MEEM
\SE@MapDeclare{iso-8859-6}{E6}{0646}% ARABIC LETTER NOON
\SE@MapDeclare{iso-8859-6}{E7}{0647}% ARABIC LETTER HEH
\SE@MapDeclare{iso-8859-6}{E8}{0648}% ARABIC LETTER WAW
\SE@MapDeclare{iso-8859-6}{E9}{0649}% ARABIC LETTER ALEF MAKSURA
\SE@MapDeclare{iso-8859-6}{EA}{064A}% ARABIC LETTER YEH
\SE@MapDeclare{iso-8859-6}{EB}{064B}% ARABIC FATHATAN
\SE@MapDeclare{iso-8859-6}{EC}{064C}% ARABIC DAMMATAN
\SE@MapDeclare{iso-8859-6}{ED}{064D}% ARABIC KASRATAN
\SE@MapDeclare{iso-8859-6}{EE}{064E}% ARABIC FATHA
\SE@MapDeclare{iso-8859-6}{EF}{064F}% ARABIC DAMMA
\SE@MapDeclare{iso-8859-6}{F0}{0650}% ARABIC KASRA
\SE@MapDeclare{iso-8859-6}{F1}{0651}% ARABIC SHADDA
\SE@MapDeclare{iso-8859-6}{F2}{0652}% ARABIC SUKUN
\endinput
%%
%% End of file `se-iso-8859-6.def'.
