%%
%% This is file `se-nextstep.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,nextstep')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-nextstep.def}[2019/11/29 v1.12 stringenc: NextStep]
\def\SE@this{nextstep}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{nextstep}{80}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{nextstep}{81}{00C0}% LATIN CAPITAL LETTER A WITH GRAVE
\SE@MapDeclare{nextstep}{82}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{nextstep}{83}{00C2}% LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{84}{00C3}% LATIN CAPITAL LETTER A WITH TILDE
\SE@MapDeclare{nextstep}{85}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{nextstep}{86}{00C5}% LATIN CAPITAL LETTER A WITH RING
\SE@MapDeclare{nextstep}{87}{00C7}% LATIN CAPITAL LETTER C WITH CEDILLA
\SE@MapDeclare{nextstep}{88}{00C8}% LATIN CAPITAL LETTER E WITH GRAVE
\SE@MapDeclare{nextstep}{89}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{nextstep}{8A}{00CA}% LATIN CAPITAL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{8B}{00CB}% LATIN CAPITAL LETTER E WITH DIAERESIS
\SE@MapDeclare{nextstep}{8C}{00CC}% LATIN CAPITAL LETTER I WITH GRAVE
\SE@MapDeclare{nextstep}{8D}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{nextstep}{8E}{00CE}% LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{8F}{00CF}% LATIN CAPITAL LETTER I WITH DIAERESIS
\SE@MapDeclare{nextstep}{90}{00D0}% LATIN CAPITAL LETTER ETH
\SE@MapDeclare{nextstep}{91}{00D1}% LATIN CAPITAL LETTER N WITH TILDE
\SE@MapDeclare{nextstep}{92}{00D2}% LATIN CAPITAL LETTER O WITH GRAVE
\SE@MapDeclare{nextstep}{93}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{nextstep}{94}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{95}{00D5}% LATIN CAPITAL LETTER O WITH TILDE
\SE@MapDeclare{nextstep}{96}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{nextstep}{97}{00D9}% LATIN CAPITAL LETTER U WITH GRAVE
\SE@MapDeclare{nextstep}{98}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{nextstep}{99}{00DB}% LATIN CAPITAL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{9A}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{nextstep}{9B}{00DD}% LATIN CAPITAL LETTER Y WITH ACUTE
\SE@MapDeclare{nextstep}{9C}{00DE}% LATIN CAPITAL LETTER THORN
\SE@MapDeclare{nextstep}{9D}{00B5}% MICRO SIGN
\SE@MapDeclare{nextstep}{9E}{00D7}% MULTIPLICATION SIGN
\SE@MapDeclare{nextstep}{9F}{00F7}% DIVISION SIGN
\SE@MapDeclare{nextstep}{A0}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{nextstep}{A1}{00A1}% INVERTED EXCLAMATION MARK
\SE@MapDeclare{nextstep}{A2}{00A2}% CENT SIGN
\SE@MapDeclare{nextstep}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{nextstep}{A4}{2044}% FRACTION SLASH
\SE@MapDeclare{nextstep}{A5}{00A5}% YEN SIGN
\SE@MapDeclare{nextstep}{A6}{0192}% LATIN SMALL LETTER F WITH HOOK
\SE@MapDeclare{nextstep}{A7}{00A7}% SECTION SIGN
\SE@MapDeclare{nextstep}{A8}{00A4}% CURRENCY SIGN
\SE@MapDeclare{nextstep}{A9}{2019}% RIGHT SINGLE QUOTATION MARK
\SE@MapDeclare{nextstep}{AA}{201C}% LEFT DOUBLE QUOTATION MARK
\SE@MapDeclare{nextstep}{AB}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{nextstep}{AC}{2039}% SINGLE LEFT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{nextstep}{AD}{203A}% SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{nextstep}{AE}{FB01}% LATIN SMALL LIGATURE FI
\SE@MapDeclare{nextstep}{AF}{FB02}% LATIN SMALL LIGATURE FL
\SE@MapDeclare{nextstep}{B0}{00AE}% REGISTERED SIGN
\SE@MapDeclare{nextstep}{B1}{2013}% EN DASH
\SE@MapDeclare{nextstep}{B2}{2020}% DAGGER
\SE@MapDeclare{nextstep}{B3}{2021}% DOUBLE DAGGER
\SE@MapDeclare{nextstep}{B4}{00B7}% MIDDLE DOT
\SE@MapDeclare{nextstep}{B5}{00A6}% BROKEN BAR
\SE@MapDeclare{nextstep}{B6}{00B6}% PILCROW SIGN
\SE@MapDeclare{nextstep}{B7}{2022}% BULLET
\SE@MapDeclare{nextstep}{B8}{201A}% SINGLE LOW-9 QUOTATION MARK
\SE@MapDeclare{nextstep}{B9}{201E}% DOUBLE LOW-9 QUOTATION MARK
\SE@MapDeclare{nextstep}{BA}{201D}% RIGHT DOUBLE QUOTATION MARK
\SE@MapDeclare{nextstep}{BB}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{nextstep}{BC}{2026}% HORIZONTAL ELLIPSIS
\SE@MapDeclare{nextstep}{BD}{2030}% PER MILLE SIGN
\SE@MapDeclare{nextstep}{BE}{00AC}% NOT SIGN
\SE@MapDeclare{nextstep}{BF}{00BF}% INVERTED QUESTION MARK
\SE@MapDeclare{nextstep}{C0}{00B9}% SUPERSCRIPT ONE
\SE@MapDeclare{nextstep}{C1}{02CB}% MODIFIER LETTER GRAVE ACCENT
\SE@MapDeclare{nextstep}{C2}{00B4}% ACUTE ACCENT
\SE@MapDeclare{nextstep}{C3}{02C6}% MODIFIER LETTER CIRCUMFLEX ACCENT
\SE@MapDeclare{nextstep}{C4}{02DC}% SMALL TILDE
\SE@MapDeclare{nextstep}{C5}{00AF}% MACRON
\SE@MapDeclare{nextstep}{C6}{02D8}% BREVE
\SE@MapDeclare{nextstep}{C7}{02D9}% DOT ABOVE
\SE@MapDeclare{nextstep}{C8}{00A8}% DIAERESIS
\SE@MapDeclare{nextstep}{C9}{00B2}% SUPERSCRIPT TWO
\SE@MapDeclare{nextstep}{CA}{02DA}% RING ABOVE
\SE@MapDeclare{nextstep}{CB}{00B8}% CEDILLA
\SE@MapDeclare{nextstep}{CC}{00B3}% SUPERSCRIPT THREE
\SE@MapDeclare{nextstep}{CD}{02DD}% DOUBLE ACUTE ACCENT
\SE@MapDeclare{nextstep}{CE}{02DB}% OGONEK
\SE@MapDeclare{nextstep}{CF}{02C7}% CARON
\SE@MapDeclare{nextstep}{D0}{2014}% EM DASH
\SE@MapDeclare{nextstep}{D1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{nextstep}{D2}{00BC}% VULGAR FRACTION ONE QUARTER
\SE@MapDeclare{nextstep}{D3}{00BD}% VULGAR FRACTION ONE HALF
\SE@MapDeclare{nextstep}{D4}{00BE}% VULGAR FRACTION THREE QUARTERS
\SE@MapDeclare{nextstep}{D5}{00E0}% LATIN SMALL LETTER A WITH GRAVE
\SE@MapDeclare{nextstep}{D6}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{nextstep}{D7}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{D8}{00E3}% LATIN SMALL LETTER A WITH TILDE
\SE@MapDeclare{nextstep}{D9}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{nextstep}{DA}{00E5}% LATIN SMALL LETTER A WITH RING ABOVE
\SE@MapDeclare{nextstep}{DB}{00E7}% LATIN SMALL LETTER C WITH CEDILLA
\SE@MapDeclare{nextstep}{DC}{00E8}% LATIN SMALL LETTER E WITH GRAVE
\SE@MapDeclare{nextstep}{DD}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{nextstep}{DE}{00EA}% LATIN SMALL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{DF}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{nextstep}{E0}{00EC}% LATIN SMALL LETTER I WITH GRAVE
\SE@MapDeclare{nextstep}{E1}{00C6}% LATIN CAPITAL LETTER AE
\SE@MapDeclare{nextstep}{E2}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{nextstep}{E3}{00AA}% FEMININE ORDINAL INDICATOR
\SE@MapDeclare{nextstep}{E4}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{E5}{00EF}% LATIN SMALL LETTER I WITH DIAERESIS
\SE@MapDeclare{nextstep}{E6}{00F0}% LATIN SMALL LETTER ETH
\SE@MapDeclare{nextstep}{E7}{00F1}% LATIN SMALL LETTER N WITH TILDE
\SE@MapDeclare{nextstep}{E8}{0141}% LATIN CAPITAL LETTER L WITH STROKE
\SE@MapDeclare{nextstep}{E9}{00D8}% LATIN CAPITAL LETTER O WITH STROKE
\SE@MapDeclare{nextstep}{EA}{0152}% LATIN CAPITAL LIGATURE OE
\SE@MapDeclare{nextstep}{EB}{00BA}% MASCULINE ORDINAL INDICATOR
\SE@MapDeclare{nextstep}{EC}{00F2}% LATIN SMALL LETTER O WITH GRAVE
\SE@MapDeclare{nextstep}{ED}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{nextstep}{EE}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{EF}{00F5}% LATIN SMALL LETTER O WITH TILDE
\SE@MapDeclare{nextstep}{F0}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{nextstep}{F1}{00E6}% LATIN SMALL LETTER AE
\SE@MapDeclare{nextstep}{F2}{00F9}% LATIN SMALL LETTER U WITH GRAVE
\SE@MapDeclare{nextstep}{F3}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{nextstep}{F4}{00FB}% LATIN SMALL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{nextstep}{F5}{0131}% LATIN SMALL LETTER DOTLESS I
\SE@MapDeclare{nextstep}{F6}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{nextstep}{F7}{00FD}% LATIN SMALL LETTER Y WITH ACUTE
\SE@MapDeclare{nextstep}{F8}{0142}% LATIN SMALL LETTER L WITH STROKE
\SE@MapDeclare{nextstep}{F9}{00F8}% LATIN SMALL LETTER O WITH STROKE
\SE@MapDeclare{nextstep}{FA}{0153}% LATIN SMALL LIGATURE OE
\SE@MapDeclare{nextstep}{FB}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{nextstep}{FC}{00FE}% LATIN SMALL LETTER THORN
\SE@MapDeclare{nextstep}{FD}{00FF}% LATIN SMALL LETTER Y WITH DIAERESIS
\endinput
%%
%% End of file `se-nextstep.def'.
