%%
%% This is file `se-cp1252.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `cp1252')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-cp1252.def}[2019/11/29 v1.12 stringenc: cp1252]
\expandafter\gdef\csname\SE@PrefixTo cp1252\endcsname#1#2#3#4{%
  \ifcase\ifnum"#1#2=\ltx@zero
           \ifnum"#3#4<"80 %
             \ltx@one
           \else
             \ifnum"#3#4>"9F %
               \ltx@one
             \else
               \ltx@zero
             \fi
           \fi
         \else
           \ltx@zero
         \fi
    \SE@MapConvertTo{cp1252}{#1#2#3#4}%
  \else
    \SE@ResultAdd{#3#4}%
  \fi
}
\expandafter\gdef\csname\SE@PrefixSurrogateTo cp1252\endcsname
    #1#2#3#4#5#6#7#8{%
  \SE@InvalidCharacter
}
\expandafter\gdef\csname\SE@PrefixFrom cp1252\endcsname#1{%
  \let\SE@next\SE@ansinew@from
  \expandafter\SE@ansinew@from#1\relax\relax
}
\gdef\SE@ansinew@from#1#2{%
  \ifx#1\relax
    \let\SE@next\relax
  \else
    \ifcase\ifnum"#1#2<"80 %
             \ltx@one
            \else
              \ifnum"#1#2>"9F %
                \ltx@one
              \else
                \ltx@zero
              \fi
            \fi
      \SE@MapConvertFrom{cp1252}{#1#2}%
    \else
      \SE@ResultAdd{00#1#2}%
    \fi
  \fi
  \SE@next
}
\SE@MapDeclare{cp1252}{80}{20AC}% EURO SIGN
\SE@MapDeclare{cp1252}{82}{201A}% SINGLE LOW-9 QUOTATION MARK
\SE@MapDeclare{cp1252}{83}{0192}% LATIN SMALL LETTER F WITH HOOK
\SE@MapDeclare{cp1252}{84}{201E}% DOUBLE LOW-9 QUOTATION MARK
\SE@MapDeclare{cp1252}{85}{2026}% HORIZONTAL ELLIPSIS
\SE@MapDeclare{cp1252}{86}{2020}% DAGGER
\SE@MapDeclare{cp1252}{87}{2021}% DOUBLE DAGGER
\SE@MapDeclare{cp1252}{88}{02C6}% MODIFIER LETTER CIRCUMFLEX ACCENT
\SE@MapDeclare{cp1252}{89}{2030}% PER MILLE SIGN
\SE@MapDeclare{cp1252}{8A}{0160}% LATIN CAPITAL LETTER S WITH CARON
\SE@MapDeclare{cp1252}{8B}{2039}% SINGLE LEFT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{cp1252}{8C}{0152}% LATIN CAPITAL LIGATURE OE
\SE@MapDeclare{cp1252}{8E}{017D}% LATIN CAPITAL LETTER Z WITH CARON
\SE@MapDeclare{cp1252}{91}{2018}% LEFT SINGLE QUOTATION MARK
\SE@MapDeclare{cp1252}{92}{2019}% RIGHT SINGLE QUOTATION MARK
\SE@MapDeclare{cp1252}{93}{201C}% LEFT DOUBLE QUOTATION MARK
\SE@MapDeclare{cp1252}{94}{201D}% RIGHT DOUBLE QUOTATION MARK
\SE@MapDeclare{cp1252}{95}{2022}% BULLET
\SE@MapDeclare{cp1252}{96}{2013}% EN DASH
\SE@MapDeclare{cp1252}{97}{2014}% EM DASH
\SE@MapDeclare{cp1252}{98}{02DC}% SMALL TILDE
\SE@MapDeclare{cp1252}{99}{2122}% TRADE MARK SIGN
\SE@MapDeclare{cp1252}{9A}{0161}% LATIN SMALL LETTER S WITH CARON
\SE@MapDeclare{cp1252}{9B}{203A}% SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{cp1252}{9C}{0153}% LATIN SMALL LIGATURE OE
\SE@MapDeclare{cp1252}{9E}{017E}% LATIN SMALL LETTER Z WITH CARON
\SE@MapDeclare{cp1252}{9F}{0178}% LATIN CAPITAL LETTER Y WITH DIAERESIS
\endinput
%%
%% End of file `se-cp1252.def'.
