%%
%% This is file `se-iso-8859-11.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,iso-8859-11')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-iso-8859-11.def}[2019/11/29 v1.12 stringenc: ISO-8859-11]
\def\SE@this{iso-8859-11}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{iso-8859-11}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{iso-8859-11}{A1}{0E01}% THAI CHARACTER KO KAI
\SE@MapDeclare{iso-8859-11}{A2}{0E02}% THAI CHARACTER KHO KHAI
\SE@MapDeclare{iso-8859-11}{A3}{0E03}% THAI CHARACTER KHO KHUAT
\SE@MapDeclare{iso-8859-11}{A4}{0E04}% THAI CHARACTER KHO KHWAI
\SE@MapDeclare{iso-8859-11}{A5}{0E05}% THAI CHARACTER KHO KHON
\SE@MapDeclare{iso-8859-11}{A6}{0E06}% THAI CHARACTER KHO RAKHANG
\SE@MapDeclare{iso-8859-11}{A7}{0E07}% THAI CHARACTER NGO NGU
\SE@MapDeclare{iso-8859-11}{A8}{0E08}% THAI CHARACTER CHO CHAN
\SE@MapDeclare{iso-8859-11}{A9}{0E09}% THAI CHARACTER CHO CHING
\SE@MapDeclare{iso-8859-11}{AA}{0E0A}% THAI CHARACTER CHO CHANG
\SE@MapDeclare{iso-8859-11}{AB}{0E0B}% THAI CHARACTER SO SO
\SE@MapDeclare{iso-8859-11}{AC}{0E0C}% THAI CHARACTER CHO CHOE
\SE@MapDeclare{iso-8859-11}{AD}{0E0D}% THAI CHARACTER YO YING
\SE@MapDeclare{iso-8859-11}{AE}{0E0E}% THAI CHARACTER DO CHADA
\SE@MapDeclare{iso-8859-11}{AF}{0E0F}% THAI CHARACTER TO PATAK
\SE@MapDeclare{iso-8859-11}{B0}{0E10}% THAI CHARACTER THO THAN
\SE@MapDeclare{iso-8859-11}{B1}{0E11}% THAI CHARACTER THO NANGMONTHO
\SE@MapDeclare{iso-8859-11}{B2}{0E12}% THAI CHARACTER THO PHUTHAO
\SE@MapDeclare{iso-8859-11}{B3}{0E13}% THAI CHARACTER NO NEN
\SE@MapDeclare{iso-8859-11}{B4}{0E14}% THAI CHARACTER DO DEK
\SE@MapDeclare{iso-8859-11}{B5}{0E15}% THAI CHARACTER TO TAO
\SE@MapDeclare{iso-8859-11}{B6}{0E16}% THAI CHARACTER THO THUNG
\SE@MapDeclare{iso-8859-11}{B7}{0E17}% THAI CHARACTER THO THAHAN
\SE@MapDeclare{iso-8859-11}{B8}{0E18}% THAI CHARACTER THO THONG
\SE@MapDeclare{iso-8859-11}{B9}{0E19}% THAI CHARACTER NO NU
\SE@MapDeclare{iso-8859-11}{BA}{0E1A}% THAI CHARACTER BO BAIMAI
\SE@MapDeclare{iso-8859-11}{BB}{0E1B}% THAI CHARACTER PO PLA
\SE@MapDeclare{iso-8859-11}{BC}{0E1C}% THAI CHARACTER PHO PHUNG
\SE@MapDeclare{iso-8859-11}{BD}{0E1D}% THAI CHARACTER FO FA
\SE@MapDeclare{iso-8859-11}{BE}{0E1E}% THAI CHARACTER PHO PHAN
\SE@MapDeclare{iso-8859-11}{BF}{0E1F}% THAI CHARACTER FO FAN
\SE@MapDeclare{iso-8859-11}{C0}{0E20}% THAI CHARACTER PHO SAMPHAO
\SE@MapDeclare{iso-8859-11}{C1}{0E21}% THAI CHARACTER MO MA
\SE@MapDeclare{iso-8859-11}{C2}{0E22}% THAI CHARACTER YO YAK
\SE@MapDeclare{iso-8859-11}{C3}{0E23}% THAI CHARACTER RO RUA
\SE@MapDeclare{iso-8859-11}{C4}{0E24}% THAI CHARACTER RU
\SE@MapDeclare{iso-8859-11}{C5}{0E25}% THAI CHARACTER LO LING
\SE@MapDeclare{iso-8859-11}{C6}{0E26}% THAI CHARACTER LU
\SE@MapDeclare{iso-8859-11}{C7}{0E27}% THAI CHARACTER WO WAEN
\SE@MapDeclare{iso-8859-11}{C8}{0E28}% THAI CHARACTER SO SALA
\SE@MapDeclare{iso-8859-11}{C9}{0E29}% THAI CHARACTER SO RUSI
\SE@MapDeclare{iso-8859-11}{CA}{0E2A}% THAI CHARACTER SO SUA
\SE@MapDeclare{iso-8859-11}{CB}{0E2B}% THAI CHARACTER HO HIP
\SE@MapDeclare{iso-8859-11}{CC}{0E2C}% THAI CHARACTER LO CHULA
\SE@MapDeclare{iso-8859-11}{CD}{0E2D}% THAI CHARACTER O ANG
\SE@MapDeclare{iso-8859-11}{CE}{0E2E}% THAI CHARACTER HO NOKHUK
\SE@MapDeclare{iso-8859-11}{CF}{0E2F}% THAI CHARACTER PAIYANNOI
\SE@MapDeclare{iso-8859-11}{D0}{0E30}% THAI CHARACTER SARA A
\SE@MapDeclare{iso-8859-11}{D1}{0E31}% THAI CHARACTER MAI HAN-AKAT
\SE@MapDeclare{iso-8859-11}{D2}{0E32}% THAI CHARACTER SARA AA
\SE@MapDeclare{iso-8859-11}{D3}{0E33}% THAI CHARACTER SARA AM
\SE@MapDeclare{iso-8859-11}{D4}{0E34}% THAI CHARACTER SARA I
\SE@MapDeclare{iso-8859-11}{D5}{0E35}% THAI CHARACTER SARA II
\SE@MapDeclare{iso-8859-11}{D6}{0E36}% THAI CHARACTER SARA UE
\SE@MapDeclare{iso-8859-11}{D7}{0E37}% THAI CHARACTER SARA UEE
\SE@MapDeclare{iso-8859-11}{D8}{0E38}% THAI CHARACTER SARA U
\SE@MapDeclare{iso-8859-11}{D9}{0E39}% THAI CHARACTER SARA UU
\SE@MapDeclare{iso-8859-11}{DA}{0E3A}% THAI CHARACTER PHINTHU
\SE@MapDeclare{iso-8859-11}{DF}{0E3F}% THAI CURRENCY SYMBOL BAHT
\SE@MapDeclare{iso-8859-11}{E0}{0E40}% THAI CHARACTER SARA E
\SE@MapDeclare{iso-8859-11}{E1}{0E41}% THAI CHARACTER SARA AE
\SE@MapDeclare{iso-8859-11}{E2}{0E42}% THAI CHARACTER SARA O
\SE@MapDeclare{iso-8859-11}{E3}{0E43}% THAI CHARACTER SARA AI MAIMUAN
\SE@MapDeclare{iso-8859-11}{E4}{0E44}% THAI CHARACTER SARA AI MAIMALAI
\SE@MapDeclare{iso-8859-11}{E5}{0E45}% THAI CHARACTER LAKKHANGYAO
\SE@MapDeclare{iso-8859-11}{E6}{0E46}% THAI CHARACTER MAIYAMOK
\SE@MapDeclare{iso-8859-11}{E7}{0E47}% THAI CHARACTER MAITAIKHU
\SE@MapDeclare{iso-8859-11}{E8}{0E48}% THAI CHARACTER MAI EK
\SE@MapDeclare{iso-8859-11}{E9}{0E49}% THAI CHARACTER MAI THO
\SE@MapDeclare{iso-8859-11}{EA}{0E4A}% THAI CHARACTER MAI TRI
\SE@MapDeclare{iso-8859-11}{EB}{0E4B}% THAI CHARACTER MAI CHATTAWA
\SE@MapDeclare{iso-8859-11}{EC}{0E4C}% THAI CHARACTER THANTHAKHAT
\SE@MapDeclare{iso-8859-11}{ED}{0E4D}% THAI CHARACTER NIKHAHIT
\SE@MapDeclare{iso-8859-11}{EE}{0E4E}% THAI CHARACTER YAMAKKAN
\SE@MapDeclare{iso-8859-11}{EF}{0E4F}% THAI CHARACTER FONGMAN
\SE@MapDeclare{iso-8859-11}{F0}{0E50}% THAI DIGIT ZERO
\SE@MapDeclare{iso-8859-11}{F1}{0E51}% THAI DIGIT ONE
\SE@MapDeclare{iso-8859-11}{F2}{0E52}% THAI DIGIT TWO
\SE@MapDeclare{iso-8859-11}{F3}{0E53}% THAI DIGIT THREE
\SE@MapDeclare{iso-8859-11}{F4}{0E54}% THAI DIGIT FOUR
\SE@MapDeclare{iso-8859-11}{F5}{0E55}% THAI DIGIT FIVE
\SE@MapDeclare{iso-8859-11}{F6}{0E56}% THAI DIGIT SIX
\SE@MapDeclare{iso-8859-11}{F7}{0E57}% THAI DIGIT SEVEN
\SE@MapDeclare{iso-8859-11}{F8}{0E58}% THAI DIGIT EIGHT
\SE@MapDeclare{iso-8859-11}{F9}{0E59}% THAI DIGIT NINE
\SE@MapDeclare{iso-8859-11}{FA}{0E5A}% THAI CHARACTER ANGKHANKHU
\SE@MapDeclare{iso-8859-11}{FB}{0E5B}% THAI CHARACTER KHOMUT
\endinput
%%
%% End of file `se-iso-8859-11.def'.
