%%
%% This is file `se-iso-8859-14.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,iso-8859-14')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-iso-8859-14.def}[2019/11/29 v1.12 stringenc: ISO-8859-14]
\def\SE@this{iso-8859-14}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{iso-8859-14}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{iso-8859-14}{A1}{1E02}% LATIN CAPITAL LETTER B WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{A2}{1E03}% LATIN SMALL LETTER B WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{iso-8859-14}{A4}{010A}% LATIN CAPITAL LETTER C WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{A5}{010B}% LATIN SMALL LETTER C WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{A6}{1E0A}% LATIN CAPITAL LETTER D WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{A7}{00A7}% SECTION SIGN
\SE@MapDeclare{iso-8859-14}{A8}{1E80}% LATIN CAPITAL LETTER W WITH GRAVE
\SE@MapDeclare{iso-8859-14}{A9}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{iso-8859-14}{AA}{1E82}% LATIN CAPITAL LETTER W WITH ACUTE
\SE@MapDeclare{iso-8859-14}{AB}{1E0B}% LATIN SMALL LETTER D WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{AC}{1EF2}% LATIN CAPITAL LETTER Y WITH GRAVE
\SE@MapDeclare{iso-8859-14}{AD}{00AD}% SOFT HYPHEN
\SE@MapDeclare{iso-8859-14}{AE}{00AE}% REGISTERED SIGN
\SE@MapDeclare{iso-8859-14}{AF}{0178}% LATIN CAPITAL LETTER Y WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{B0}{1E1E}% LATIN CAPITAL LETTER F WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{B1}{1E1F}% LATIN SMALL LETTER F WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{B2}{0120}% LATIN CAPITAL LETTER G WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{B3}{0121}% LATIN SMALL LETTER G WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{B4}{1E40}% LATIN CAPITAL LETTER M WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{B5}{1E41}% LATIN SMALL LETTER M WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{B6}{00B6}% PILCROW SIGN
\SE@MapDeclare{iso-8859-14}{B7}{1E56}% LATIN CAPITAL LETTER P WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{B8}{1E81}% LATIN SMALL LETTER W WITH GRAVE
\SE@MapDeclare{iso-8859-14}{B9}{1E57}% LATIN SMALL LETTER P WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{BA}{1E83}% LATIN SMALL LETTER W WITH ACUTE
\SE@MapDeclare{iso-8859-14}{BB}{1E60}% LATIN CAPITAL LETTER S WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{BC}{1EF3}% LATIN SMALL LETTER Y WITH GRAVE
\SE@MapDeclare{iso-8859-14}{BD}{1E84}% LATIN CAPITAL LETTER W WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{BE}{1E85}% LATIN SMALL LETTER W WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{BF}{1E61}% LATIN SMALL LETTER S WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{C0}{00C0}% LATIN CAPITAL LETTER A WITH GRAVE
\SE@MapDeclare{iso-8859-14}{C1}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{iso-8859-14}{C2}{00C2}% LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{C3}{00C3}% LATIN CAPITAL LETTER A WITH TILDE
\SE@MapDeclare{iso-8859-14}{C4}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{C5}{00C5}% LATIN CAPITAL LETTER A WITH RING ABOVE
\SE@MapDeclare{iso-8859-14}{C6}{00C6}% LATIN CAPITAL LETTER AE
\SE@MapDeclare{iso-8859-14}{C7}{00C7}% LATIN CAPITAL LETTER C WITH CEDILLA
\SE@MapDeclare{iso-8859-14}{C8}{00C8}% LATIN CAPITAL LETTER E WITH GRAVE
\SE@MapDeclare{iso-8859-14}{C9}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{iso-8859-14}{CA}{00CA}% LATIN CAPITAL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{CB}{00CB}% LATIN CAPITAL LETTER E WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{CC}{00CC}% LATIN CAPITAL LETTER I WITH GRAVE
\SE@MapDeclare{iso-8859-14}{CD}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{iso-8859-14}{CE}{00CE}% LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{CF}{00CF}% LATIN CAPITAL LETTER I WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{D0}{0174}% LATIN CAPITAL LETTER W WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{D1}{00D1}% LATIN CAPITAL LETTER N WITH TILDE
\SE@MapDeclare{iso-8859-14}{D2}{00D2}% LATIN CAPITAL LETTER O WITH GRAVE
\SE@MapDeclare{iso-8859-14}{D3}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{iso-8859-14}{D4}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{D5}{00D5}% LATIN CAPITAL LETTER O WITH TILDE
\SE@MapDeclare{iso-8859-14}{D6}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{D7}{1E6A}% LATIN CAPITAL LETTER T WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{D8}{00D8}% LATIN CAPITAL LETTER O WITH STROKE
\SE@MapDeclare{iso-8859-14}{D9}{00D9}% LATIN CAPITAL LETTER U WITH GRAVE
\SE@MapDeclare{iso-8859-14}{DA}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{iso-8859-14}{DB}{00DB}% LATIN CAPITAL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{DC}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{DD}{00DD}% LATIN CAPITAL LETTER Y WITH ACUTE
\SE@MapDeclare{iso-8859-14}{DE}{0176}% LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{DF}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{iso-8859-14}{E0}{00E0}% LATIN SMALL LETTER A WITH GRAVE
\SE@MapDeclare{iso-8859-14}{E1}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{iso-8859-14}{E2}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{E3}{00E3}% LATIN SMALL LETTER A WITH TILDE
\SE@MapDeclare{iso-8859-14}{E4}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{E5}{00E5}% LATIN SMALL LETTER A WITH RING ABOVE
\SE@MapDeclare{iso-8859-14}{E6}{00E6}% LATIN SMALL LETTER AE
\SE@MapDeclare{iso-8859-14}{E7}{00E7}% LATIN SMALL LETTER C WITH CEDILLA
\SE@MapDeclare{iso-8859-14}{E8}{00E8}% LATIN SMALL LETTER E WITH GRAVE
\SE@MapDeclare{iso-8859-14}{E9}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{iso-8859-14}{EA}{00EA}% LATIN SMALL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{EB}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{EC}{00EC}% LATIN SMALL LETTER I WITH GRAVE
\SE@MapDeclare{iso-8859-14}{ED}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{iso-8859-14}{EE}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{EF}{00EF}% LATIN SMALL LETTER I WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{F0}{0175}% LATIN SMALL LETTER W WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{F1}{00F1}% LATIN SMALL LETTER N WITH TILDE
\SE@MapDeclare{iso-8859-14}{F2}{00F2}% LATIN SMALL LETTER O WITH GRAVE
\SE@MapDeclare{iso-8859-14}{F3}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{iso-8859-14}{F4}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{F5}{00F5}% LATIN SMALL LETTER O WITH TILDE
\SE@MapDeclare{iso-8859-14}{F6}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{F7}{1E6B}% LATIN SMALL LETTER T WITH DOT ABOVE
\SE@MapDeclare{iso-8859-14}{F8}{00F8}% LATIN SMALL LETTER O WITH STROKE
\SE@MapDeclare{iso-8859-14}{F9}{00F9}% LATIN SMALL LETTER U WITH GRAVE
\SE@MapDeclare{iso-8859-14}{FA}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{iso-8859-14}{FB}{00FB}% LATIN SMALL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{FC}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{iso-8859-14}{FD}{00FD}% LATIN SMALL LETTER Y WITH ACUTE
\SE@MapDeclare{iso-8859-14}{FE}{0177}% LATIN SMALL LETTER Y WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-14}{FF}{00FF}% LATIN SMALL LETTER Y WITH DIAERESIS
\endinput
%%
%% End of file `se-iso-8859-14.def'.
