%%
%% This is file `se-mac-cyrillic.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,mac-cyrillic')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-mac-cyrillic.def}[2019/11/29 v1.12 stringenc: Mac OS Cyrillic]
\def\SE@this{mac-cyrillic}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{mac-cyrillic}{80}{0410}% CYRILLIC CAPITAL LETTER A
\SE@MapDeclare{mac-cyrillic}{81}{0411}% CYRILLIC CAPITAL LETTER BE
\SE@MapDeclare{mac-cyrillic}{82}{0412}% CYRILLIC CAPITAL LETTER VE
\SE@MapDeclare{mac-cyrillic}{83}{0413}% CYRILLIC CAPITAL LETTER GHE
\SE@MapDeclare{mac-cyrillic}{84}{0414}% CYRILLIC CAPITAL LETTER DE
\SE@MapDeclare{mac-cyrillic}{85}{0415}% CYRILLIC CAPITAL LETTER IE
\SE@MapDeclare{mac-cyrillic}{86}{0416}% CYRILLIC CAPITAL LETTER ZHE
\SE@MapDeclare{mac-cyrillic}{87}{0417}% CYRILLIC CAPITAL LETTER ZE
\SE@MapDeclare{mac-cyrillic}{88}{0418}% CYRILLIC CAPITAL LETTER I
\SE@MapDeclare{mac-cyrillic}{89}{0419}% CYRILLIC CAPITAL LETTER SHORT I
\SE@MapDeclare{mac-cyrillic}{8A}{041A}% CYRILLIC CAPITAL LETTER KA
\SE@MapDeclare{mac-cyrillic}{8B}{041B}% CYRILLIC CAPITAL LETTER EL
\SE@MapDeclare{mac-cyrillic}{8C}{041C}% CYRILLIC CAPITAL LETTER EM
\SE@MapDeclare{mac-cyrillic}{8D}{041D}% CYRILLIC CAPITAL LETTER EN
\SE@MapDeclare{mac-cyrillic}{8E}{041E}% CYRILLIC CAPITAL LETTER O
\SE@MapDeclare{mac-cyrillic}{8F}{041F}% CYRILLIC CAPITAL LETTER PE
\SE@MapDeclare{mac-cyrillic}{90}{0420}% CYRILLIC CAPITAL LETTER ER
\SE@MapDeclare{mac-cyrillic}{91}{0421}% CYRILLIC CAPITAL LETTER ES
\SE@MapDeclare{mac-cyrillic}{92}{0422}% CYRILLIC CAPITAL LETTER TE
\SE@MapDeclare{mac-cyrillic}{93}{0423}% CYRILLIC CAPITAL LETTER U
\SE@MapDeclare{mac-cyrillic}{94}{0424}% CYRILLIC CAPITAL LETTER EF
\SE@MapDeclare{mac-cyrillic}{95}{0425}% CYRILLIC CAPITAL LETTER HA
\SE@MapDeclare{mac-cyrillic}{96}{0426}% CYRILLIC CAPITAL LETTER TSE
\SE@MapDeclare{mac-cyrillic}{97}{0427}% CYRILLIC CAPITAL LETTER CHE
\SE@MapDeclare{mac-cyrillic}{98}{0428}% CYRILLIC CAPITAL LETTER SHA
\SE@MapDeclare{mac-cyrillic}{99}{0429}% CYRILLIC CAPITAL LETTER SHCHA
\SE@MapDeclare{mac-cyrillic}{9A}{042A}% CYRILLIC CAPITAL LETTER HARD SIGN
\SE@MapDeclare{mac-cyrillic}{9B}{042B}% CYRILLIC CAPITAL LETTER YERU
\SE@MapDeclare{mac-cyrillic}{9C}{042C}% CYRILLIC CAPITAL LETTER SOFT SIGN
\SE@MapDeclare{mac-cyrillic}{9D}{042D}% CYRILLIC CAPITAL LETTER E
\SE@MapDeclare{mac-cyrillic}{9E}{042E}% CYRILLIC CAPITAL LETTER YU
\SE@MapDeclare{mac-cyrillic}{9F}{042F}% CYRILLIC CAPITAL LETTER YA
\SE@MapDeclare{mac-cyrillic}{A0}{2020}% DAGGER
\SE@MapDeclare{mac-cyrillic}{A1}{00B0}% DEGREE SIGN
\SE@MapDeclare{mac-cyrillic}{A2}{0490}% CYRILLIC CAPITAL LETTER GHE WITH UPTURN
\SE@MapDeclare{mac-cyrillic}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{mac-cyrillic}{A4}{00A7}% SECTION SIGN
\SE@MapDeclare{mac-cyrillic}{A5}{2022}% BULLET
\SE@MapDeclare{mac-cyrillic}{A6}{00B6}% PILCROW SIGN
\SE@MapDeclare{mac-cyrillic}{A7}{0406}% CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I
\SE@MapDeclare{mac-cyrillic}{A8}{00AE}% REGISTERED SIGN
\SE@MapDeclare{mac-cyrillic}{A9}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{mac-cyrillic}{AA}{2122}% TRADE MARK SIGN
\SE@MapDeclare{mac-cyrillic}{AB}{0402}% CYRILLIC CAPITAL LETTER DJE
\SE@MapDeclare{mac-cyrillic}{AC}{0452}% CYRILLIC SMALL LETTER DJE
\SE@MapDeclare{mac-cyrillic}{AD}{2260}% NOT EQUAL TO
\SE@MapDeclare{mac-cyrillic}{AE}{0403}% CYRILLIC CAPITAL LETTER GJE
\SE@MapDeclare{mac-cyrillic}{AF}{0453}% CYRILLIC SMALL LETTER GJE
\SE@MapDeclare{mac-cyrillic}{B0}{221E}% INFINITY
\SE@MapDeclare{mac-cyrillic}{B1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{mac-cyrillic}{B2}{2264}% LESS-THAN OR EQUAL TO
\SE@MapDeclare{mac-cyrillic}{B3}{2265}% GREATER-THAN OR EQUAL TO
\SE@MapDeclare{mac-cyrillic}{B4}{0456}% CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I
\SE@MapDeclare{mac-cyrillic}{B5}{00B5}% MICRO SIGN
\SE@MapDeclare{mac-cyrillic}{B6}{0491}% CYRILLIC SMALL LETTER GHE WITH UPTURN
\SE@MapDeclare{mac-cyrillic}{B7}{0408}% CYRILLIC CAPITAL LETTER JE
\SE@MapDeclare{mac-cyrillic}{B8}{0404}% CYRILLIC CAPITAL LETTER UKRAINIAN IE
\SE@MapDeclare{mac-cyrillic}{B9}{0454}% CYRILLIC SMALL LETTER UKRAINIAN IE
\SE@MapDeclare{mac-cyrillic}{BA}{0407}% CYRILLIC CAPITAL LETTER YI
\SE@MapDeclare{mac-cyrillic}{BB}{0457}% CYRILLIC SMALL LETTER YI
\SE@MapDeclare{mac-cyrillic}{BC}{0409}% CYRILLIC CAPITAL LETTER LJE
\SE@MapDeclare{mac-cyrillic}{BD}{0459}% CYRILLIC SMALL LETTER LJE
\SE@MapDeclare{mac-cyrillic}{BE}{040A}% CYRILLIC CAPITAL LETTER NJE
\SE@MapDeclare{mac-cyrillic}{BF}{045A}% CYRILLIC SMALL LETTER NJE
\SE@MapDeclare{mac-cyrillic}{C0}{0458}% CYRILLIC SMALL LETTER JE
\SE@MapDeclare{mac-cyrillic}{C1}{0405}% CYRILLIC CAPITAL LETTER DZE
\SE@MapDeclare{mac-cyrillic}{C2}{00AC}% NOT SIGN
\SE@MapDeclare{mac-cyrillic}{C3}{221A}% SQUARE ROOT
\SE@MapDeclare{mac-cyrillic}{C4}{0192}% LATIN SMALL LETTER F WITH HOOK
\SE@MapDeclare{mac-cyrillic}{C5}{2248}% ALMOST EQUAL TO
\SE@MapDeclare{mac-cyrillic}{C6}{2206}% INCREMENT
\SE@MapDeclare{mac-cyrillic}{C7}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{mac-cyrillic}{C8}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{mac-cyrillic}{C9}{2026}% HORIZONTAL ELLIPSIS
\SE@MapDeclare{mac-cyrillic}{CA}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{mac-cyrillic}{CB}{040B}% CYRILLIC CAPITAL LETTER TSHE
\SE@MapDeclare{mac-cyrillic}{CC}{045B}% CYRILLIC SMALL LETTER TSHE
\SE@MapDeclare{mac-cyrillic}{CD}{040C}% CYRILLIC CAPITAL LETTER KJE
\SE@MapDeclare{mac-cyrillic}{CE}{045C}% CYRILLIC SMALL LETTER KJE
\SE@MapDeclare{mac-cyrillic}{CF}{0455}% CYRILLIC SMALL LETTER DZE
\SE@MapDeclare{mac-cyrillic}{D0}{2013}% EN DASH
\SE@MapDeclare{mac-cyrillic}{D1}{2014}% EM DASH
\SE@MapDeclare{mac-cyrillic}{D2}{201C}% LEFT DOUBLE QUOTATION MARK
\SE@MapDeclare{mac-cyrillic}{D3}{201D}% RIGHT DOUBLE QUOTATION MARK
\SE@MapDeclare{mac-cyrillic}{D4}{2018}% LEFT SINGLE QUOTATION MARK
\SE@MapDeclare{mac-cyrillic}{D5}{2019}% RIGHT SINGLE QUOTATION MARK
\SE@MapDeclare{mac-cyrillic}{D6}{00F7}% DIVISION SIGN
\SE@MapDeclare{mac-cyrillic}{D7}{201E}% DOUBLE LOW-9 QUOTATION MARK
\SE@MapDeclare{mac-cyrillic}{D8}{040E}% CYRILLIC CAPITAL LETTER SHORT U
\SE@MapDeclare{mac-cyrillic}{D9}{045E}% CYRILLIC SMALL LETTER SHORT U
\SE@MapDeclare{mac-cyrillic}{DA}{040F}% CYRILLIC CAPITAL LETTER DZHE
\SE@MapDeclare{mac-cyrillic}{DB}{045F}% CYRILLIC SMALL LETTER DZHE
\SE@MapDeclare{mac-cyrillic}{DC}{2116}% NUMERO SIGN
\SE@MapDeclare{mac-cyrillic}{DD}{0401}% CYRILLIC CAPITAL LETTER IO
\SE@MapDeclare{mac-cyrillic}{DE}{0451}% CYRILLIC SMALL LETTER IO
\SE@MapDeclare{mac-cyrillic}{DF}{044F}% CYRILLIC SMALL LETTER YA
\SE@MapDeclare{mac-cyrillic}{E0}{0430}% CYRILLIC SMALL LETTER A
\SE@MapDeclare{mac-cyrillic}{E1}{0431}% CYRILLIC SMALL LETTER BE
\SE@MapDeclare{mac-cyrillic}{E2}{0432}% CYRILLIC SMALL LETTER VE
\SE@MapDeclare{mac-cyrillic}{E3}{0433}% CYRILLIC SMALL LETTER GHE
\SE@MapDeclare{mac-cyrillic}{E4}{0434}% CYRILLIC SMALL LETTER DE
\SE@MapDeclare{mac-cyrillic}{E5}{0435}% CYRILLIC SMALL LETTER IE
\SE@MapDeclare{mac-cyrillic}{E6}{0436}% CYRILLIC SMALL LETTER ZHE
\SE@MapDeclare{mac-cyrillic}{E7}{0437}% CYRILLIC SMALL LETTER ZE
\SE@MapDeclare{mac-cyrillic}{E8}{0438}% CYRILLIC SMALL LETTER I
\SE@MapDeclare{mac-cyrillic}{E9}{0439}% CYRILLIC SMALL LETTER SHORT I
\SE@MapDeclare{mac-cyrillic}{EA}{043A}% CYRILLIC SMALL LETTER KA
\SE@MapDeclare{mac-cyrillic}{EB}{043B}% CYRILLIC SMALL LETTER EL
\SE@MapDeclare{mac-cyrillic}{EC}{043C}% CYRILLIC SMALL LETTER EM
\SE@MapDeclare{mac-cyrillic}{ED}{043D}% CYRILLIC SMALL LETTER EN
\SE@MapDeclare{mac-cyrillic}{EE}{043E}% CYRILLIC SMALL LETTER O
\SE@MapDeclare{mac-cyrillic}{EF}{043F}% CYRILLIC SMALL LETTER PE
\SE@MapDeclare{mac-cyrillic}{F0}{0440}% CYRILLIC SMALL LETTER ER
\SE@MapDeclare{mac-cyrillic}{F1}{0441}% CYRILLIC SMALL LETTER ES
\SE@MapDeclare{mac-cyrillic}{F2}{0442}% CYRILLIC SMALL LETTER TE
\SE@MapDeclare{mac-cyrillic}{F3}{0443}% CYRILLIC SMALL LETTER U
\SE@MapDeclare{mac-cyrillic}{F4}{0444}% CYRILLIC SMALL LETTER EF
\SE@MapDeclare{mac-cyrillic}{F5}{0445}% CYRILLIC SMALL LETTER HA
\SE@MapDeclare{mac-cyrillic}{F6}{0446}% CYRILLIC SMALL LETTER TSE
\SE@MapDeclare{mac-cyrillic}{F7}{0447}% CYRILLIC SMALL LETTER CHE
\SE@MapDeclare{mac-cyrillic}{F8}{0448}% CYRILLIC SMALL LETTER SHA
\SE@MapDeclare{mac-cyrillic}{F9}{0449}% CYRILLIC SMALL LETTER SHCHA
\SE@MapDeclare{mac-cyrillic}{FA}{044A}% CYRILLIC SMALL LETTER HARD SIGN
\SE@MapDeclare{mac-cyrillic}{FB}{044B}% CYRILLIC SMALL LETTER YERU
\SE@MapDeclare{mac-cyrillic}{FC}{044C}% CYRILLIC SMALL LETTER SOFT SIGN
\SE@MapDeclare{mac-cyrillic}{FD}{044D}% CYRILLIC SMALL LETTER E
\SE@MapDeclare{mac-cyrillic}{FE}{044E}% CYRILLIC SMALL LETTER YU
\SE@MapDeclare{mac-cyrillic}{FF}{20AC}% EURO SIGN
\endinput
%%
%% End of file `se-mac-cyrillic.def'.
