%%
%% This is file `se-cp1257.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,cp1257')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-cp1257.def}[2019/11/29 v1.12 stringenc: cp1257]
\def\SE@this{cp1257}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{cp1257}{80}{20AC}% EURO SIGN
\SE@MapDeclare{cp1257}{82}{201A}% SINGLE LOW-9 QUOTATION MARK
\SE@MapDeclare{cp1257}{84}{201E}% DOUBLE LOW-9 QUOTATION MARK
\SE@MapDeclare{cp1257}{85}{2026}% HORIZONTAL ELLIPSIS
\SE@MapDeclare{cp1257}{86}{2020}% DAGGER
\SE@MapDeclare{cp1257}{87}{2021}% DOUBLE DAGGER
\SE@MapDeclare{cp1257}{89}{2030}% PER MILLE SIGN
\SE@MapDeclare{cp1257}{8B}{2039}% SINGLE LEFT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{cp1257}{8D}{00A8}% DIAERESIS
\SE@MapDeclare{cp1257}{8E}{02C7}% CARON
\SE@MapDeclare{cp1257}{8F}{00B8}% CEDILLA
\SE@MapDeclare{cp1257}{91}{2018}% LEFT SINGLE QUOTATION MARK
\SE@MapDeclare{cp1257}{92}{2019}% RIGHT SINGLE QUOTATION MARK
\SE@MapDeclare{cp1257}{93}{201C}% LEFT DOUBLE QUOTATION MARK
\SE@MapDeclare{cp1257}{94}{201D}% RIGHT DOUBLE QUOTATION MARK
\SE@MapDeclare{cp1257}{95}{2022}% BULLET
\SE@MapDeclare{cp1257}{96}{2013}% EN DASH
\SE@MapDeclare{cp1257}{97}{2014}% EM DASH
\SE@MapDeclare{cp1257}{99}{2122}% TRADE MARK SIGN
\SE@MapDeclare{cp1257}{9B}{203A}% SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{cp1257}{9D}{00AF}% MACRON
\SE@MapDeclare{cp1257}{9E}{02DB}% OGONEK
\SE@MapDeclare{cp1257}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{cp1257}{A2}{00A2}% CENT SIGN
\SE@MapDeclare{cp1257}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{cp1257}{A4}{00A4}% CURRENCY SIGN
\SE@MapDeclare{cp1257}{A6}{00A6}% BROKEN BAR
\SE@MapDeclare{cp1257}{A7}{00A7}% SECTION SIGN
\SE@MapDeclare{cp1257}{A8}{00D8}% LATIN CAPITAL LETTER O WITH STROKE
\SE@MapDeclare{cp1257}{A9}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{cp1257}{AA}{0156}% LATIN CAPITAL LETTER R WITH CEDILLA
\SE@MapDeclare{cp1257}{AB}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{cp1257}{AC}{00AC}% NOT SIGN
\SE@MapDeclare{cp1257}{AD}{00AD}% SOFT HYPHEN
\SE@MapDeclare{cp1257}{AE}{00AE}% REGISTERED SIGN
\SE@MapDeclare{cp1257}{AF}{00C6}% LATIN CAPITAL LETTER AE
\SE@MapDeclare{cp1257}{B0}{00B0}% DEGREE SIGN
\SE@MapDeclare{cp1257}{B1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{cp1257}{B2}{00B2}% SUPERSCRIPT TWO
\SE@MapDeclare{cp1257}{B3}{00B3}% SUPERSCRIPT THREE
\SE@MapDeclare{cp1257}{B4}{00B4}% ACUTE ACCENT
\SE@MapDeclare{cp1257}{B5}{00B5}% MICRO SIGN
\SE@MapDeclare{cp1257}{B6}{00B6}% PILCROW SIGN
\SE@MapDeclare{cp1257}{B7}{00B7}% MIDDLE DOT
\SE@MapDeclare{cp1257}{B8}{00F8}% LATIN SMALL LETTER O WITH STROKE
\SE@MapDeclare{cp1257}{B9}{00B9}% SUPERSCRIPT ONE
\SE@MapDeclare{cp1257}{BA}{0157}% LATIN SMALL LETTER R WITH CEDILLA
\SE@MapDeclare{cp1257}{BB}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{cp1257}{BC}{00BC}% VULGAR FRACTION ONE QUARTER
\SE@MapDeclare{cp1257}{BD}{00BD}% VULGAR FRACTION ONE HALF
\SE@MapDeclare{cp1257}{BE}{00BE}% VULGAR FRACTION THREE QUARTERS
\SE@MapDeclare{cp1257}{BF}{00E6}% LATIN SMALL LETTER AE
\SE@MapDeclare{cp1257}{C0}{0104}% LATIN CAPITAL LETTER A WITH OGONEK
\SE@MapDeclare{cp1257}{C1}{012E}% LATIN CAPITAL LETTER I WITH OGONEK
\SE@MapDeclare{cp1257}{C2}{0100}% LATIN CAPITAL LETTER A WITH MACRON
\SE@MapDeclare{cp1257}{C3}{0106}% LATIN CAPITAL LETTER C WITH ACUTE
\SE@MapDeclare{cp1257}{C4}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp1257}{C5}{00C5}% LATIN CAPITAL LETTER A WITH RING ABOVE
\SE@MapDeclare{cp1257}{C6}{0118}% LATIN CAPITAL LETTER E WITH OGONEK
\SE@MapDeclare{cp1257}{C7}{0112}% LATIN CAPITAL LETTER E WITH MACRON
\SE@MapDeclare{cp1257}{C8}{010C}% LATIN CAPITAL LETTER C WITH CARON
\SE@MapDeclare{cp1257}{C9}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{cp1257}{CA}{0179}% LATIN CAPITAL LETTER Z WITH ACUTE
\SE@MapDeclare{cp1257}{CB}{0116}% LATIN CAPITAL LETTER E WITH DOT ABOVE
\SE@MapDeclare{cp1257}{CC}{0122}% LATIN CAPITAL LETTER G WITH CEDILLA
\SE@MapDeclare{cp1257}{CD}{0136}% LATIN CAPITAL LETTER K WITH CEDILLA
\SE@MapDeclare{cp1257}{CE}{012A}% LATIN CAPITAL LETTER I WITH MACRON
\SE@MapDeclare{cp1257}{CF}{013B}% LATIN CAPITAL LETTER L WITH CEDILLA
\SE@MapDeclare{cp1257}{D0}{0160}% LATIN CAPITAL LETTER S WITH CARON
\SE@MapDeclare{cp1257}{D1}{0143}% LATIN CAPITAL LETTER N WITH ACUTE
\SE@MapDeclare{cp1257}{D2}{0145}% LATIN CAPITAL LETTER N WITH CEDILLA
\SE@MapDeclare{cp1257}{D3}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{cp1257}{D4}{014C}% LATIN CAPITAL LETTER O WITH MACRON
\SE@MapDeclare{cp1257}{D5}{00D5}% LATIN CAPITAL LETTER O WITH TILDE
\SE@MapDeclare{cp1257}{D6}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp1257}{D7}{00D7}% MULTIPLICATION SIGN
\SE@MapDeclare{cp1257}{D8}{0172}% LATIN CAPITAL LETTER U WITH OGONEK
\SE@MapDeclare{cp1257}{D9}{0141}% LATIN CAPITAL LETTER L WITH STROKE
\SE@MapDeclare{cp1257}{DA}{015A}% LATIN CAPITAL LETTER S WITH ACUTE
\SE@MapDeclare{cp1257}{DB}{016A}% LATIN CAPITAL LETTER U WITH MACRON
\SE@MapDeclare{cp1257}{DC}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp1257}{DD}{017B}% LATIN CAPITAL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{cp1257}{DE}{017D}% LATIN CAPITAL LETTER Z WITH CARON
\SE@MapDeclare{cp1257}{DF}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{cp1257}{E0}{0105}% LATIN SMALL LETTER A WITH OGONEK
\SE@MapDeclare{cp1257}{E1}{012F}% LATIN SMALL LETTER I WITH OGONEK
\SE@MapDeclare{cp1257}{E2}{0101}% LATIN SMALL LETTER A WITH MACRON
\SE@MapDeclare{cp1257}{E3}{0107}% LATIN SMALL LETTER C WITH ACUTE
\SE@MapDeclare{cp1257}{E4}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp1257}{E5}{00E5}% LATIN SMALL LETTER A WITH RING ABOVE
\SE@MapDeclare{cp1257}{E6}{0119}% LATIN SMALL LETTER E WITH OGONEK
\SE@MapDeclare{cp1257}{E7}{0113}% LATIN SMALL LETTER E WITH MACRON
\SE@MapDeclare{cp1257}{E8}{010D}% LATIN SMALL LETTER C WITH CARON
\SE@MapDeclare{cp1257}{E9}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{cp1257}{EA}{017A}% LATIN SMALL LETTER Z WITH ACUTE
\SE@MapDeclare{cp1257}{EB}{0117}% LATIN SMALL LETTER E WITH DOT ABOVE
\SE@MapDeclare{cp1257}{EC}{0123}% LATIN SMALL LETTER G WITH CEDILLA
\SE@MapDeclare{cp1257}{ED}{0137}% LATIN SMALL LETTER K WITH CEDILLA
\SE@MapDeclare{cp1257}{EE}{012B}% LATIN SMALL LETTER I WITH MACRON
\SE@MapDeclare{cp1257}{EF}{013C}% LATIN SMALL LETTER L WITH CEDILLA
\SE@MapDeclare{cp1257}{F0}{0161}% LATIN SMALL LETTER S WITH CARON
\SE@MapDeclare{cp1257}{F1}{0144}% LATIN SMALL LETTER N WITH ACUTE
\SE@MapDeclare{cp1257}{F2}{0146}% LATIN SMALL LETTER N WITH CEDILLA
\SE@MapDeclare{cp1257}{F3}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{cp1257}{F4}{014D}% LATIN SMALL LETTER O WITH MACRON
\SE@MapDeclare{cp1257}{F5}{00F5}% LATIN SMALL LETTER O WITH TILDE
\SE@MapDeclare{cp1257}{F6}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp1257}{F7}{00F7}% DIVISION SIGN
\SE@MapDeclare{cp1257}{F8}{0173}% LATIN SMALL LETTER U WITH OGONEK
\SE@MapDeclare{cp1257}{F9}{0142}% LATIN SMALL LETTER L WITH STROKE
\SE@MapDeclare{cp1257}{FA}{015B}% LATIN SMALL LETTER S WITH ACUTE
\SE@MapDeclare{cp1257}{FB}{016B}% LATIN SMALL LETTER U WITH MACRON
\SE@MapDeclare{cp1257}{FC}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp1257}{FD}{017C}% LATIN SMALL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{cp1257}{FE}{017E}% LATIN SMALL LETTER Z WITH CARON
\SE@MapDeclare{cp1257}{FF}{02D9}% DOT ABOVE
\endinput
%%
%% End of file `se-cp1257.def'.
