%%
%% This is file `se-cp866.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,cp866')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-cp866.def}[2019/11/29 v1.12 stringenc: cp866]
\def\SE@this{cp866}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{cp866}{80}{0410}% CYRILLIC CAPITAL LETTER A
\SE@MapDeclare{cp866}{81}{0411}% CYRILLIC CAPITAL LETTER BE
\SE@MapDeclare{cp866}{82}{0412}% CYRILLIC CAPITAL LETTER VE
\SE@MapDeclare{cp866}{83}{0413}% CYRILLIC CAPITAL LETTER GHE
\SE@MapDeclare{cp866}{84}{0414}% CYRILLIC CAPITAL LETTER DE
\SE@MapDeclare{cp866}{85}{0415}% CYRILLIC CAPITAL LETTER IE
\SE@MapDeclare{cp866}{86}{0416}% CYRILLIC CAPITAL LETTER ZHE
\SE@MapDeclare{cp866}{87}{0417}% CYRILLIC CAPITAL LETTER ZE
\SE@MapDeclare{cp866}{88}{0418}% CYRILLIC CAPITAL LETTER I
\SE@MapDeclare{cp866}{89}{0419}% CYRILLIC CAPITAL LETTER SHORT I
\SE@MapDeclare{cp866}{8A}{041A}% CYRILLIC CAPITAL LETTER KA
\SE@MapDeclare{cp866}{8B}{041B}% CYRILLIC CAPITAL LETTER EL
\SE@MapDeclare{cp866}{8C}{041C}% CYRILLIC CAPITAL LETTER EM
\SE@MapDeclare{cp866}{8D}{041D}% CYRILLIC CAPITAL LETTER EN
\SE@MapDeclare{cp866}{8E}{041E}% CYRILLIC CAPITAL LETTER O
\SE@MapDeclare{cp866}{8F}{041F}% CYRILLIC CAPITAL LETTER PE
\SE@MapDeclare{cp866}{90}{0420}% CYRILLIC CAPITAL LETTER ER
\SE@MapDeclare{cp866}{91}{0421}% CYRILLIC CAPITAL LETTER ES
\SE@MapDeclare{cp866}{92}{0422}% CYRILLIC CAPITAL LETTER TE
\SE@MapDeclare{cp866}{93}{0423}% CYRILLIC CAPITAL LETTER U
\SE@MapDeclare{cp866}{94}{0424}% CYRILLIC CAPITAL LETTER EF
\SE@MapDeclare{cp866}{95}{0425}% CYRILLIC CAPITAL LETTER HA
\SE@MapDeclare{cp866}{96}{0426}% CYRILLIC CAPITAL LETTER TSE
\SE@MapDeclare{cp866}{97}{0427}% CYRILLIC CAPITAL LETTER CHE
\SE@MapDeclare{cp866}{98}{0428}% CYRILLIC CAPITAL LETTER SHA
\SE@MapDeclare{cp866}{99}{0429}% CYRILLIC CAPITAL LETTER SHCHA
\SE@MapDeclare{cp866}{9A}{042A}% CYRILLIC CAPITAL LETTER HARD SIGN
\SE@MapDeclare{cp866}{9B}{042B}% CYRILLIC CAPITAL LETTER YERU
\SE@MapDeclare{cp866}{9C}{042C}% CYRILLIC CAPITAL LETTER SOFT SIGN
\SE@MapDeclare{cp866}{9D}{042D}% CYRILLIC CAPITAL LETTER E
\SE@MapDeclare{cp866}{9E}{042E}% CYRILLIC CAPITAL LETTER YU
\SE@MapDeclare{cp866}{9F}{042F}% CYRILLIC CAPITAL LETTER YA
\SE@MapDeclare{cp866}{A0}{0430}% CYRILLIC SMALL LETTER A
\SE@MapDeclare{cp866}{A1}{0431}% CYRILLIC SMALL LETTER BE
\SE@MapDeclare{cp866}{A2}{0432}% CYRILLIC SMALL LETTER VE
\SE@MapDeclare{cp866}{A3}{0433}% CYRILLIC SMALL LETTER GHE
\SE@MapDeclare{cp866}{A4}{0434}% CYRILLIC SMALL LETTER DE
\SE@MapDeclare{cp866}{A5}{0435}% CYRILLIC SMALL LETTER IE
\SE@MapDeclare{cp866}{A6}{0436}% CYRILLIC SMALL LETTER ZHE
\SE@MapDeclare{cp866}{A7}{0437}% CYRILLIC SMALL LETTER ZE
\SE@MapDeclare{cp866}{A8}{0438}% CYRILLIC SMALL LETTER I
\SE@MapDeclare{cp866}{A9}{0439}% CYRILLIC SMALL LETTER SHORT I
\SE@MapDeclare{cp866}{AA}{043A}% CYRILLIC SMALL LETTER KA
\SE@MapDeclare{cp866}{AB}{043B}% CYRILLIC SMALL LETTER EL
\SE@MapDeclare{cp866}{AC}{043C}% CYRILLIC SMALL LETTER EM
\SE@MapDeclare{cp866}{AD}{043D}% CYRILLIC SMALL LETTER EN
\SE@MapDeclare{cp866}{AE}{043E}% CYRILLIC SMALL LETTER O
\SE@MapDeclare{cp866}{AF}{043F}% CYRILLIC SMALL LETTER PE
\SE@MapDeclare{cp866}{B0}{2591}% LIGHT SHADE
\SE@MapDeclare{cp866}{B1}{2592}% MEDIUM SHADE
\SE@MapDeclare{cp866}{B2}{2593}% DARK SHADE
\SE@MapDeclare{cp866}{B3}{2502}% BOX DRAWINGS LIGHT VERTICAL
\SE@MapDeclare{cp866}{B4}{2524}% BOX DRAWINGS LIGHT VERTICAL AND LEFT
\SE@MapDeclare{cp866}{B5}{2561}% BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE
\SE@MapDeclare{cp866}{B6}{2562}% BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE
\SE@MapDeclare{cp866}{B7}{2556}% BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE
\SE@MapDeclare{cp866}{B8}{2555}% BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE
\SE@MapDeclare{cp866}{B9}{2563}% BOX DRAWINGS DOUBLE VERTICAL AND LEFT
\SE@MapDeclare{cp866}{BA}{2551}% BOX DRAWINGS DOUBLE VERTICAL
\SE@MapDeclare{cp866}{BB}{2557}% BOX DRAWINGS DOUBLE DOWN AND LEFT
\SE@MapDeclare{cp866}{BC}{255D}% BOX DRAWINGS DOUBLE UP AND LEFT
\SE@MapDeclare{cp866}{BD}{255C}% BOX DRAWINGS UP DOUBLE AND LEFT SINGLE
\SE@MapDeclare{cp866}{BE}{255B}% BOX DRAWINGS UP SINGLE AND LEFT DOUBLE
\SE@MapDeclare{cp866}{BF}{2510}% BOX DRAWINGS LIGHT DOWN AND LEFT
\SE@MapDeclare{cp866}{C0}{2514}% BOX DRAWINGS LIGHT UP AND RIGHT
\SE@MapDeclare{cp866}{C1}{2534}% BOX DRAWINGS LIGHT UP AND HORIZONTAL
\SE@MapDeclare{cp866}{C2}{252C}% BOX DRAWINGS LIGHT DOWN AND HORIZONTAL
\SE@MapDeclare{cp866}{C3}{251C}% BOX DRAWINGS LIGHT VERTICAL AND RIGHT
\SE@MapDeclare{cp866}{C4}{2500}% BOX DRAWINGS LIGHT HORIZONTAL
\SE@MapDeclare{cp866}{C5}{253C}% BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL
\SE@MapDeclare{cp866}{C6}{255E}% BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE
\SE@MapDeclare{cp866}{C7}{255F}% BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE
\SE@MapDeclare{cp866}{C8}{255A}% BOX DRAWINGS DOUBLE UP AND RIGHT
\SE@MapDeclare{cp866}{C9}{2554}% BOX DRAWINGS DOUBLE DOWN AND RIGHT
\SE@MapDeclare{cp866}{CA}{2569}% BOX DRAWINGS DOUBLE UP AND HORIZONTAL
\SE@MapDeclare{cp866}{CB}{2566}% BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL
\SE@MapDeclare{cp866}{CC}{2560}% BOX DRAWINGS DOUBLE VERTICAL AND RIGHT
\SE@MapDeclare{cp866}{CD}{2550}% BOX DRAWINGS DOUBLE HORIZONTAL
\SE@MapDeclare{cp866}{CE}{256C}% BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL
\SE@MapDeclare{cp866}{CF}{2567}% BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE
\SE@MapDeclare{cp866}{D0}{2568}% BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE
\SE@MapDeclare{cp866}{D1}{2564}% BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE
\SE@MapDeclare{cp866}{D2}{2565}% BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE
\SE@MapDeclare{cp866}{D3}{2559}% BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE
\SE@MapDeclare{cp866}{D4}{2558}% BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE
\SE@MapDeclare{cp866}{D5}{2552}% BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE
\SE@MapDeclare{cp866}{D6}{2553}% BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE
\SE@MapDeclare{cp866}{D7}{256B}% BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE
\SE@MapDeclare{cp866}{D8}{256A}% BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE
\SE@MapDeclare{cp866}{D9}{2518}% BOX DRAWINGS LIGHT UP AND LEFT
\SE@MapDeclare{cp866}{DA}{250C}% BOX DRAWINGS LIGHT DOWN AND RIGHT
\SE@MapDeclare{cp866}{DB}{2588}% FULL BLOCK
\SE@MapDeclare{cp866}{DC}{2584}% LOWER HALF BLOCK
\SE@MapDeclare{cp866}{DD}{258C}% LEFT HALF BLOCK
\SE@MapDeclare{cp866}{DE}{2590}% RIGHT HALF BLOCK
\SE@MapDeclare{cp866}{DF}{2580}% UPPER HALF BLOCK
\SE@MapDeclare{cp866}{E0}{0440}% CYRILLIC SMALL LETTER ER
\SE@MapDeclare{cp866}{E1}{0441}% CYRILLIC SMALL LETTER ES
\SE@MapDeclare{cp866}{E2}{0442}% CYRILLIC SMALL LETTER TE
\SE@MapDeclare{cp866}{E3}{0443}% CYRILLIC SMALL LETTER U
\SE@MapDeclare{cp866}{E4}{0444}% CYRILLIC SMALL LETTER EF
\SE@MapDeclare{cp866}{E5}{0445}% CYRILLIC SMALL LETTER HA
\SE@MapDeclare{cp866}{E6}{0446}% CYRILLIC SMALL LETTER TSE
\SE@MapDeclare{cp866}{E7}{0447}% CYRILLIC SMALL LETTER CHE
\SE@MapDeclare{cp866}{E8}{0448}% CYRILLIC SMALL LETTER SHA
\SE@MapDeclare{cp866}{E9}{0449}% CYRILLIC SMALL LETTER SHCHA
\SE@MapDeclare{cp866}{EA}{044A}% CYRILLIC SMALL LETTER HARD SIGN
\SE@MapDeclare{cp866}{EB}{044B}% CYRILLIC SMALL LETTER YERU
\SE@MapDeclare{cp866}{EC}{044C}% CYRILLIC SMALL LETTER SOFT SIGN
\SE@MapDeclare{cp866}{ED}{044D}% CYRILLIC SMALL LETTER E
\SE@MapDeclare{cp866}{EE}{044E}% CYRILLIC SMALL LETTER YU
\SE@MapDeclare{cp866}{EF}{044F}% CYRILLIC SMALL LETTER YA
\SE@MapDeclare{cp866}{F0}{0401}% CYRILLIC CAPITAL LETTER IO
\SE@MapDeclare{cp866}{F1}{0451}% CYRILLIC SMALL LETTER IO
\SE@MapDeclare{cp866}{F2}{0404}% CYRILLIC CAPITAL LETTER UKRAINIAN IE
\SE@MapDeclare{cp866}{F3}{0454}% CYRILLIC SMALL LETTER UKRAINIAN IE
\SE@MapDeclare{cp866}{F4}{0407}% CYRILLIC CAPITAL LETTER YI
\SE@MapDeclare{cp866}{F5}{0457}% CYRILLIC SMALL LETTER YI
\SE@MapDeclare{cp866}{F6}{040E}% CYRILLIC CAPITAL LETTER SHORT U
\SE@MapDeclare{cp866}{F7}{045E}% CYRILLIC SMALL LETTER SHORT U
\SE@MapDeclare{cp866}{F8}{00B0}% DEGREE SIGN
\SE@MapDeclare{cp866}{F9}{2219}% BULLET OPERATOR
\SE@MapDeclare{cp866}{FA}{00B7}% MIDDLE DOT
\SE@MapDeclare{cp866}{FB}{221A}% SQUARE ROOT
\SE@MapDeclare{cp866}{FC}{2116}% NUMERO SIGN
\SE@MapDeclare{cp866}{FD}{00A4}% CURRENCY SIGN
\SE@MapDeclare{cp866}{FE}{25A0}% BLACK SQUARE
\SE@MapDeclare{cp866}{FF}{00A0}% NO-BREAK SPACE
\endinput
%%
%% End of file `se-cp866.def'.
