%%
%% This is file `se-iso-8859-7.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,iso-8859-7')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-iso-8859-7.def}[2019/11/29 v1.12 stringenc: ISO-8859-7]
\def\SE@this{iso-8859-7}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{iso-8859-7}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{iso-8859-7}{A1}{2018}% LEFT SINGLE QUOTATION MARK
\SE@MapDeclare{iso-8859-7}{A2}{2019}% RIGHT SINGLE QUOTATION MARK
\SE@MapDeclare{iso-8859-7}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{iso-8859-7}{A4}{20AC}% EURO SIGN
\SE@MapDeclare{iso-8859-7}{A5}{20AF}% DRACHMA SIGN
\SE@MapDeclare{iso-8859-7}{A6}{00A6}% BROKEN BAR
\SE@MapDeclare{iso-8859-7}{A7}{00A7}% SECTION SIGN
\SE@MapDeclare{iso-8859-7}{A8}{00A8}% DIAERESIS
\SE@MapDeclare{iso-8859-7}{A9}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{iso-8859-7}{AA}{037A}% GREEK YPOGEGRAMMENI
\SE@MapDeclare{iso-8859-7}{AB}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{iso-8859-7}{AC}{00AC}% NOT SIGN
\SE@MapDeclare{iso-8859-7}{AD}{00AD}% SOFT HYPHEN
\SE@MapDeclare{iso-8859-7}{AF}{2015}% HORIZONTAL BAR
\SE@MapDeclare{iso-8859-7}{B0}{00B0}% DEGREE SIGN
\SE@MapDeclare{iso-8859-7}{B1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{iso-8859-7}{B2}{00B2}% SUPERSCRIPT TWO
\SE@MapDeclare{iso-8859-7}{B3}{00B3}% SUPERSCRIPT THREE
\SE@MapDeclare{iso-8859-7}{B4}{0384}% GREEK TONOS
\SE@MapDeclare{iso-8859-7}{B5}{0385}% GREEK DIALYTIKA TONOS
\SE@MapDeclare{iso-8859-7}{B6}{0386}% GREEK CAPITAL LETTER ALPHA WITH TONOS
\SE@MapDeclare{iso-8859-7}{B7}{00B7}% MIDDLE DOT
\SE@MapDeclare{iso-8859-7}{B8}{0388}% GREEK CAPITAL LETTER EPSILON WITH TONOS
\SE@MapDeclare{iso-8859-7}{B9}{0389}% GREEK CAPITAL LETTER ETA WITH TONOS
\SE@MapDeclare{iso-8859-7}{BA}{038A}% GREEK CAPITAL LETTER IOTA WITH TONOS
\SE@MapDeclare{iso-8859-7}{BB}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{iso-8859-7}{BC}{038C}% GREEK CAPITAL LETTER OMICRON WITH TONOS
\SE@MapDeclare{iso-8859-7}{BD}{00BD}% VULGAR FRACTION ONE HALF
\SE@MapDeclare{iso-8859-7}{BE}{038E}% GREEK CAPITAL LETTER UPSILON WITH TONOS
\SE@MapDeclare{iso-8859-7}{BF}{038F}% GREEK CAPITAL LETTER OMEGA WITH TONOS
\SE@MapDeclare{iso-8859-7}{C0}{0390}% GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS
\SE@MapDeclare{iso-8859-7}{C1}{0391}% GREEK CAPITAL LETTER ALPHA
\SE@MapDeclare{iso-8859-7}{C2}{0392}% GREEK CAPITAL LETTER BETA
\SE@MapDeclare{iso-8859-7}{C3}{0393}% GREEK CAPITAL LETTER GAMMA
\SE@MapDeclare{iso-8859-7}{C4}{0394}% GREEK CAPITAL LETTER DELTA
\SE@MapDeclare{iso-8859-7}{C5}{0395}% GREEK CAPITAL LETTER EPSILON
\SE@MapDeclare{iso-8859-7}{C6}{0396}% GREEK CAPITAL LETTER ZETA
\SE@MapDeclare{iso-8859-7}{C7}{0397}% GREEK CAPITAL LETTER ETA
\SE@MapDeclare{iso-8859-7}{C8}{0398}% GREEK CAPITAL LETTER THETA
\SE@MapDeclare{iso-8859-7}{C9}{0399}% GREEK CAPITAL LETTER IOTA
\SE@MapDeclare{iso-8859-7}{CA}{039A}% GREEK CAPITAL LETTER KAPPA
\SE@MapDeclare{iso-8859-7}{CB}{039B}% GREEK CAPITAL LETTER LAMDA
\SE@MapDeclare{iso-8859-7}{CC}{039C}% GREEK CAPITAL LETTER MU
\SE@MapDeclare{iso-8859-7}{CD}{039D}% GREEK CAPITAL LETTER NU
\SE@MapDeclare{iso-8859-7}{CE}{039E}% GREEK CAPITAL LETTER XI
\SE@MapDeclare{iso-8859-7}{CF}{039F}% GREEK CAPITAL LETTER OMICRON
\SE@MapDeclare{iso-8859-7}{D0}{03A0}% GREEK CAPITAL LETTER PI
\SE@MapDeclare{iso-8859-7}{D1}{03A1}% GREEK CAPITAL LETTER RHO
\SE@MapDeclare{iso-8859-7}{D3}{03A3}% GREEK CAPITAL LETTER SIGMA
\SE@MapDeclare{iso-8859-7}{D4}{03A4}% GREEK CAPITAL LETTER TAU
\SE@MapDeclare{iso-8859-7}{D5}{03A5}% GREEK CAPITAL LETTER UPSILON
\SE@MapDeclare{iso-8859-7}{D6}{03A6}% GREEK CAPITAL LETTER PHI
\SE@MapDeclare{iso-8859-7}{D7}{03A7}% GREEK CAPITAL LETTER CHI
\SE@MapDeclare{iso-8859-7}{D8}{03A8}% GREEK CAPITAL LETTER PSI
\SE@MapDeclare{iso-8859-7}{D9}{03A9}% GREEK CAPITAL LETTER OMEGA
\SE@MapDeclare{iso-8859-7}{DA}{03AA}% GREEK CAPITAL LETTER IOTA WITH DIALYTIKA
\SE@MapDeclare{iso-8859-7}{DB}{03AB}% GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA
\SE@MapDeclare{iso-8859-7}{DC}{03AC}% GREEK SMALL LETTER ALPHA WITH TONOS
\SE@MapDeclare{iso-8859-7}{DD}{03AD}% GREEK SMALL LETTER EPSILON WITH TONOS
\SE@MapDeclare{iso-8859-7}{DE}{03AE}% GREEK SMALL LETTER ETA WITH TONOS
\SE@MapDeclare{iso-8859-7}{DF}{03AF}% GREEK SMALL LETTER IOTA WITH TONOS
\SE@MapDeclare{iso-8859-7}{E0}{03B0}% GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS
\SE@MapDeclare{iso-8859-7}{E1}{03B1}% GREEK SMALL LETTER ALPHA
\SE@MapDeclare{iso-8859-7}{E2}{03B2}% GREEK SMALL LETTER BETA
\SE@MapDeclare{iso-8859-7}{E3}{03B3}% GREEK SMALL LETTER GAMMA
\SE@MapDeclare{iso-8859-7}{E4}{03B4}% GREEK SMALL LETTER DELTA
\SE@MapDeclare{iso-8859-7}{E5}{03B5}% GREEK SMALL LETTER EPSILON
\SE@MapDeclare{iso-8859-7}{E6}{03B6}% GREEK SMALL LETTER ZETA
\SE@MapDeclare{iso-8859-7}{E7}{03B7}% GREEK SMALL LETTER ETA
\SE@MapDeclare{iso-8859-7}{E8}{03B8}% GREEK SMALL LETTER THETA
\SE@MapDeclare{iso-8859-7}{E9}{03B9}% GREEK SMALL LETTER IOTA
\SE@MapDeclare{iso-8859-7}{EA}{03BA}% GREEK SMALL LETTER KAPPA
\SE@MapDeclare{iso-8859-7}{EB}{03BB}% GREEK SMALL LETTER LAMDA
\SE@MapDeclare{iso-8859-7}{EC}{03BC}% GREEK SMALL LETTER MU
\SE@MapDeclare{iso-8859-7}{ED}{03BD}% GREEK SMALL LETTER NU
\SE@MapDeclare{iso-8859-7}{EE}{03BE}% GREEK SMALL LETTER XI
\SE@MapDeclare{iso-8859-7}{EF}{03BF}% GREEK SMALL LETTER OMICRON
\SE@MapDeclare{iso-8859-7}{F0}{03C0}% GREEK SMALL LETTER PI
\SE@MapDeclare{iso-8859-7}{F1}{03C1}% GREEK SMALL LETTER RHO
\SE@MapDeclare{iso-8859-7}{F2}{03C2}% GREEK SMALL LETTER FINAL SIGMA
\SE@MapDeclare{iso-8859-7}{F3}{03C3}% GREEK SMALL LETTER SIGMA
\SE@MapDeclare{iso-8859-7}{F4}{03C4}% GREEK SMALL LETTER TAU
\SE@MapDeclare{iso-8859-7}{F5}{03C5}% GREEK SMALL LETTER UPSILON
\SE@MapDeclare{iso-8859-7}{F6}{03C6}% GREEK SMALL LETTER PHI
\SE@MapDeclare{iso-8859-7}{F7}{03C7}% GREEK SMALL LETTER CHI
\SE@MapDeclare{iso-8859-7}{F8}{03C8}% GREEK SMALL LETTER PSI
\SE@MapDeclare{iso-8859-7}{F9}{03C9}% GREEK SMALL LETTER OMEGA
\SE@MapDeclare{iso-8859-7}{FA}{03CA}% GREEK SMALL LETTER IOTA WITH DIALYTIKA
\SE@MapDeclare{iso-8859-7}{FB}{03CB}% GREEK SMALL LETTER UPSILON WITH DIALYTIKA
\SE@MapDeclare{iso-8859-7}{FC}{03CC}% GREEK SMALL LETTER OMICRON WITH TONOS
\SE@MapDeclare{iso-8859-7}{FD}{03CD}% GREEK SMALL LETTER UPSILON WITH TONOS
\SE@MapDeclare{iso-8859-7}{FE}{03CE}% GREEK SMALL LETTER OMEGA WITH TONOS
\endinput
%%
%% End of file `se-iso-8859-7.def'.
