%%
%% This is file `se-cp858.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,cp858')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-cp858.def}[2019/11/29 v1.12 stringenc: cp858]
\def\SE@this{cp858}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{cp858}{80}{00C7}% LATIN CAPITAL LETTER C WITH CEDILLA
\SE@MapDeclare{cp858}{81}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp858}{82}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{cp858}{83}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{84}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp858}{85}{00E0}% LATIN SMALL LETTER A WITH GRAVE
\SE@MapDeclare{cp858}{86}{00E5}% LATIN SMALL LETTER A WITH RING ABOVE
\SE@MapDeclare{cp858}{87}{00E7}% LATIN SMALL LETTER C WITH CEDILLA
\SE@MapDeclare{cp858}{88}{00EA}% LATIN SMALL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{89}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{cp858}{8A}{00E8}% LATIN SMALL LETTER E WITH GRAVE
\SE@MapDeclare{cp858}{8B}{00EF}% LATIN SMALL LETTER I WITH DIAERESIS
\SE@MapDeclare{cp858}{8C}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{8D}{00EC}% LATIN SMALL LETTER I WITH GRAVE
\SE@MapDeclare{cp858}{8E}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp858}{8F}{00C5}% LATIN CAPITAL LETTER A WITH RING ABOVE
\SE@MapDeclare{cp858}{90}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{cp858}{91}{00E6}% LATIN SMALL LIGATURE AE
\SE@MapDeclare{cp858}{92}{00C6}% LATIN CAPITAL LIGATURE AE
\SE@MapDeclare{cp858}{93}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{94}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp858}{95}{00F2}% LATIN SMALL LETTER O WITH GRAVE
\SE@MapDeclare{cp858}{96}{00FB}% LATIN SMALL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{97}{00F9}% LATIN SMALL LETTER U WITH GRAVE
\SE@MapDeclare{cp858}{98}{00FF}% LATIN SMALL LETTER Y WITH DIAERESIS
\SE@MapDeclare{cp858}{99}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp858}{9A}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp858}{9B}{00F8}% LATIN SMALL LETTER O WITH STROKE
\SE@MapDeclare{cp858}{9C}{00A3}% POUND SIGN
\SE@MapDeclare{cp858}{9D}{00D8}% LATIN CAPITAL LETTER O WITH STROKE
\SE@MapDeclare{cp858}{9E}{00D7}% MULTIPLICATION SIGN
\SE@MapDeclare{cp858}{9F}{0192}% LATIN SMALL LETTER F WITH HOOK
\SE@MapDeclare{cp858}{A0}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{cp858}{A1}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{cp858}{A2}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{cp858}{A3}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{cp858}{A4}{00F1}% LATIN SMALL LETTER N WITH TILDE
\SE@MapDeclare{cp858}{A5}{00D1}% LATIN CAPITAL LETTER N WITH TILDE
\SE@MapDeclare{cp858}{A6}{00AA}% FEMININE ORDINAL INDICATOR
\SE@MapDeclare{cp858}{A7}{00BA}% MASCULINE ORDINAL INDICATOR
\SE@MapDeclare{cp858}{A8}{00BF}% INVERTED QUESTION MARK
\SE@MapDeclare{cp858}{A9}{00AE}% REGISTERED SIGN
\SE@MapDeclare{cp858}{AA}{00AC}% NOT SIGN
\SE@MapDeclare{cp858}{AB}{00BD}% VULGAR FRACTION ONE HALF
\SE@MapDeclare{cp858}{AC}{00BC}% VULGAR FRACTION ONE QUARTER
\SE@MapDeclare{cp858}{AD}{00A1}% INVERTED EXCLAMATION MARK
\SE@MapDeclare{cp858}{AE}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{cp858}{AF}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{cp858}{B0}{2591}% LIGHT SHADE
\SE@MapDeclare{cp858}{B1}{2592}% MEDIUM SHADE
\SE@MapDeclare{cp858}{B2}{2593}% DARK SHADE
\SE@MapDeclare{cp858}{B3}{2502}% BOX DRAWINGS LIGHT VERTICAL
\SE@MapDeclare{cp858}{B4}{2524}% BOX DRAWINGS LIGHT VERTICAL AND LEFT
\SE@MapDeclare{cp858}{B5}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{cp858}{B6}{00C2}% LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{B7}{00C0}% LATIN CAPITAL LETTER A WITH GRAVE
\SE@MapDeclare{cp858}{B8}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{cp858}{B9}{2563}% BOX DRAWINGS DOUBLE VERTICAL AND LEFT
\SE@MapDeclare{cp858}{BA}{2551}% BOX DRAWINGS DOUBLE VERTICAL
\SE@MapDeclare{cp858}{BB}{2557}% BOX DRAWINGS DOUBLE DOWN AND LEFT
\SE@MapDeclare{cp858}{BC}{255D}% BOX DRAWINGS DOUBLE UP AND LEFT
\SE@MapDeclare{cp858}{BD}{00A2}% CENT SIGN
\SE@MapDeclare{cp858}{BE}{00A5}% YEN SIGN
\SE@MapDeclare{cp858}{BF}{2510}% BOX DRAWINGS LIGHT DOWN AND LEFT
\SE@MapDeclare{cp858}{C0}{2514}% BOX DRAWINGS LIGHT UP AND RIGHT
\SE@MapDeclare{cp858}{C1}{2534}% BOX DRAWINGS LIGHT UP AND HORIZONTAL
\SE@MapDeclare{cp858}{C2}{252C}% BOX DRAWINGS LIGHT DOWN AND HORIZONTAL
\SE@MapDeclare{cp858}{C3}{251C}% BOX DRAWINGS LIGHT VERTICAL AND RIGHT
\SE@MapDeclare{cp858}{C4}{2500}% BOX DRAWINGS LIGHT HORIZONTAL
\SE@MapDeclare{cp858}{C5}{253C}% BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL
\SE@MapDeclare{cp858}{C6}{00E3}% LATIN SMALL LETTER A WITH TILDE
\SE@MapDeclare{cp858}{C7}{00C3}% LATIN CAPITAL LETTER A WITH TILDE
\SE@MapDeclare{cp858}{C8}{255A}% BOX DRAWINGS DOUBLE UP AND RIGHT
\SE@MapDeclare{cp858}{C9}{2554}% BOX DRAWINGS DOUBLE DOWN AND RIGHT
\SE@MapDeclare{cp858}{CA}{2569}% BOX DRAWINGS DOUBLE UP AND HORIZONTAL
\SE@MapDeclare{cp858}{CB}{2566}% BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL
\SE@MapDeclare{cp858}{CC}{2560}% BOX DRAWINGS DOUBLE VERTICAL AND RIGHT
\SE@MapDeclare{cp858}{CD}{2550}% BOX DRAWINGS DOUBLE HORIZONTAL
\SE@MapDeclare{cp858}{CE}{256C}% BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL
\SE@MapDeclare{cp858}{CF}{00A4}% CURRENCY SIGN
\SE@MapDeclare{cp858}{D0}{00F0}% LATIN SMALL LETTER ETH
\SE@MapDeclare{cp858}{D1}{00D0}% LATIN CAPITAL LETTER ETH
\SE@MapDeclare{cp858}{D2}{00CA}% LATIN CAPITAL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{D3}{00CB}% LATIN CAPITAL LETTER E WITH DIAERESIS
\SE@MapDeclare{cp858}{D4}{00C8}% LATIN CAPITAL LETTER E WITH GRAVE
\SE@MapDeclare{cp858}{D5}{20AC}% EURO SIGN
\SE@MapDeclare{cp858}{D6}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{cp858}{D7}{00CE}% LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{D8}{00CF}% LATIN CAPITAL LETTER I WITH DIAERESIS
\SE@MapDeclare{cp858}{D9}{2518}% BOX DRAWINGS LIGHT UP AND LEFT
\SE@MapDeclare{cp858}{DA}{250C}% BOX DRAWINGS LIGHT DOWN AND RIGHT
\SE@MapDeclare{cp858}{DB}{2588}% FULL BLOCK
\SE@MapDeclare{cp858}{DC}{2584}% LOWER HALF BLOCK
\SE@MapDeclare{cp858}{DD}{00A6}% BROKEN BAR
\SE@MapDeclare{cp858}{DE}{00CC}% LATIN CAPITAL LETTER I WITH GRAVE
\SE@MapDeclare{cp858}{DF}{2580}% UPPER HALF BLOCK
\SE@MapDeclare{cp858}{E0}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{cp858}{E1}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{cp858}{E2}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{E3}{00D2}% LATIN CAPITAL LETTER O WITH GRAVE
\SE@MapDeclare{cp858}{E4}{00F5}% LATIN SMALL LETTER O WITH TILDE
\SE@MapDeclare{cp858}{E5}{00D5}% LATIN CAPITAL LETTER O WITH TILDE
\SE@MapDeclare{cp858}{E6}{00B5}% MICRO SIGN
\SE@MapDeclare{cp858}{E7}{00FE}% LATIN SMALL LETTER THORN
\SE@MapDeclare{cp858}{E8}{00DE}% LATIN CAPITAL LETTER THORN
\SE@MapDeclare{cp858}{E9}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{cp858}{EA}{00DB}% LATIN CAPITAL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{cp858}{EB}{00D9}% LATIN CAPITAL LETTER U WITH GRAVE
\SE@MapDeclare{cp858}{EC}{00FD}% LATIN SMALL LETTER Y WITH ACUTE
\SE@MapDeclare{cp858}{ED}{00DD}% LATIN CAPITAL LETTER Y WITH ACUTE
\SE@MapDeclare{cp858}{EE}{00AF}% MACRON
\SE@MapDeclare{cp858}{EF}{00B4}% ACUTE ACCENT
\SE@MapDeclare{cp858}{F0}{00AD}% SOFT HYPHEN
\SE@MapDeclare{cp858}{F1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{cp858}{F2}{2017}% DOUBLE LOW LINE
\SE@MapDeclare{cp858}{F3}{00BE}% VULGAR FRACTION THREE QUARTERS
\SE@MapDeclare{cp858}{F4}{00B6}% PILCROW SIGN
\SE@MapDeclare{cp858}{F5}{00A7}% SECTION SIGN
\SE@MapDeclare{cp858}{F6}{00F7}% DIVISION SIGN
\SE@MapDeclare{cp858}{F7}{00B8}% CEDILLA
\SE@MapDeclare{cp858}{F8}{00B0}% DEGREE SIGN
\SE@MapDeclare{cp858}{F9}{00A8}% DIAERESIS
\SE@MapDeclare{cp858}{FA}{00B7}% MIDDLE DOT
\SE@MapDeclare{cp858}{FB}{00B9}% SUPERSCRIPT ONE
\SE@MapDeclare{cp858}{FC}{00B3}% SUPERSCRIPT THREE
\SE@MapDeclare{cp858}{FD}{00B2}% SUPERSCRIPT TWO
\SE@MapDeclare{cp858}{FE}{25A0}% BLACK SQUARE
\SE@MapDeclare{cp858}{FF}{00A0}% NO-BREAK SPACE
\endinput
%%
%% End of file `se-cp858.def'.
