%%
%% This is file `se-cp852.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,cp852')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-cp852.def}[2019/11/29 v1.12 stringenc: cp852]
\def\SE@this{cp852}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{cp852}{80}{00C7}% LATIN CAPITAL LETTER C WITH CEDILLA
\SE@MapDeclare{cp852}{81}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp852}{82}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{cp852}{83}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{cp852}{84}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp852}{85}{016F}% LATIN SMALL LETTER U WITH RING ABOVE
\SE@MapDeclare{cp852}{86}{0107}% LATIN SMALL LETTER C WITH ACUTE
\SE@MapDeclare{cp852}{87}{00E7}% LATIN SMALL LETTER C WITH CEDILLA
\SE@MapDeclare{cp852}{88}{0142}% LATIN SMALL LETTER L WITH STROKE
\SE@MapDeclare{cp852}{89}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{cp852}{8A}{0150}% LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
\SE@MapDeclare{cp852}{8B}{0151}% LATIN SMALL LETTER O WITH DOUBLE ACUTE
\SE@MapDeclare{cp852}{8C}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{cp852}{8D}{0179}% LATIN CAPITAL LETTER Z WITH ACUTE
\SE@MapDeclare{cp852}{8E}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{cp852}{8F}{0106}% LATIN CAPITAL LETTER C WITH ACUTE
\SE@MapDeclare{cp852}{90}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{cp852}{91}{0139}% LATIN CAPITAL LETTER L WITH ACUTE
\SE@MapDeclare{cp852}{92}{013A}% LATIN SMALL LETTER L WITH ACUTE
\SE@MapDeclare{cp852}{93}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{cp852}{94}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp852}{95}{013D}% LATIN CAPITAL LETTER L WITH CARON
\SE@MapDeclare{cp852}{96}{013E}% LATIN SMALL LETTER L WITH CARON
\SE@MapDeclare{cp852}{97}{015A}% LATIN CAPITAL LETTER S WITH ACUTE
\SE@MapDeclare{cp852}{98}{015B}% LATIN SMALL LETTER S WITH ACUTE
\SE@MapDeclare{cp852}{99}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{cp852}{9A}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{cp852}{9B}{0164}% LATIN CAPITAL LETTER T WITH CARON
\SE@MapDeclare{cp852}{9C}{0165}% LATIN SMALL LETTER T WITH CARON
\SE@MapDeclare{cp852}{9D}{0141}% LATIN CAPITAL LETTER L WITH STROKE
\SE@MapDeclare{cp852}{9E}{00D7}% MULTIPLICATION SIGN
\SE@MapDeclare{cp852}{9F}{010D}% LATIN SMALL LETTER C WITH CARON
\SE@MapDeclare{cp852}{A0}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{cp852}{A1}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{cp852}{A2}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{cp852}{A3}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{cp852}{A4}{0104}% LATIN CAPITAL LETTER A WITH OGONEK
\SE@MapDeclare{cp852}{A5}{0105}% LATIN SMALL LETTER A WITH OGONEK
\SE@MapDeclare{cp852}{A6}{017D}% LATIN CAPITAL LETTER Z WITH CARON
\SE@MapDeclare{cp852}{A7}{017E}% LATIN SMALL LETTER Z WITH CARON
\SE@MapDeclare{cp852}{A8}{0118}% LATIN CAPITAL LETTER E WITH OGONEK
\SE@MapDeclare{cp852}{A9}{0119}% LATIN SMALL LETTER E WITH OGONEK
\SE@MapDeclare{cp852}{AA}{00AC}% NOT SIGN
\SE@MapDeclare{cp852}{AB}{017A}% LATIN SMALL LETTER Z WITH ACUTE
\SE@MapDeclare{cp852}{AC}{010C}% LATIN CAPITAL LETTER C WITH CARON
\SE@MapDeclare{cp852}{AD}{015F}% LATIN SMALL LETTER S WITH CEDILLA
\SE@MapDeclare{cp852}{AE}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{cp852}{AF}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{cp852}{B0}{2591}% LIGHT SHADE
\SE@MapDeclare{cp852}{B1}{2592}% MEDIUM SHADE
\SE@MapDeclare{cp852}{B2}{2593}% DARK SHADE
\SE@MapDeclare{cp852}{B3}{2502}% BOX DRAWINGS LIGHT VERTICAL
\SE@MapDeclare{cp852}{B4}{2524}% BOX DRAWINGS LIGHT VERTICAL AND LEFT
\SE@MapDeclare{cp852}{B5}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{cp852}{B6}{00C2}% LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{cp852}{B7}{011A}% LATIN CAPITAL LETTER E WITH CARON
\SE@MapDeclare{cp852}{B8}{015E}% LATIN CAPITAL LETTER S WITH CEDILLA
\SE@MapDeclare{cp852}{B9}{2563}% BOX DRAWINGS DOUBLE VERTICAL AND LEFT
\SE@MapDeclare{cp852}{BA}{2551}% BOX DRAWINGS DOUBLE VERTICAL
\SE@MapDeclare{cp852}{BB}{2557}% BOX DRAWINGS DOUBLE DOWN AND LEFT
\SE@MapDeclare{cp852}{BC}{255D}% BOX DRAWINGS DOUBLE UP AND LEFT
\SE@MapDeclare{cp852}{BD}{017B}% LATIN CAPITAL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{cp852}{BE}{017C}% LATIN SMALL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{cp852}{BF}{2510}% BOX DRAWINGS LIGHT DOWN AND LEFT
\SE@MapDeclare{cp852}{C0}{2514}% BOX DRAWINGS LIGHT UP AND RIGHT
\SE@MapDeclare{cp852}{C1}{2534}% BOX DRAWINGS LIGHT UP AND HORIZONTAL
\SE@MapDeclare{cp852}{C2}{252C}% BOX DRAWINGS LIGHT DOWN AND HORIZONTAL
\SE@MapDeclare{cp852}{C3}{251C}% BOX DRAWINGS LIGHT VERTICAL AND RIGHT
\SE@MapDeclare{cp852}{C4}{2500}% BOX DRAWINGS LIGHT HORIZONTAL
\SE@MapDeclare{cp852}{C5}{253C}% BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL
\SE@MapDeclare{cp852}{C6}{0102}% LATIN CAPITAL LETTER A WITH BREVE
\SE@MapDeclare{cp852}{C7}{0103}% LATIN SMALL LETTER A WITH BREVE
\SE@MapDeclare{cp852}{C8}{255A}% BOX DRAWINGS DOUBLE UP AND RIGHT
\SE@MapDeclare{cp852}{C9}{2554}% BOX DRAWINGS DOUBLE DOWN AND RIGHT
\SE@MapDeclare{cp852}{CA}{2569}% BOX DRAWINGS DOUBLE UP AND HORIZONTAL
\SE@MapDeclare{cp852}{CB}{2566}% BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL
\SE@MapDeclare{cp852}{CC}{2560}% BOX DRAWINGS DOUBLE VERTICAL AND RIGHT
\SE@MapDeclare{cp852}{CD}{2550}% BOX DRAWINGS DOUBLE HORIZONTAL
\SE@MapDeclare{cp852}{CE}{256C}% BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL
\SE@MapDeclare{cp852}{CF}{00A4}% CURRENCY SIGN
\SE@MapDeclare{cp852}{D0}{0111}% LATIN SMALL LETTER D WITH STROKE
\SE@MapDeclare{cp852}{D1}{0110}% LATIN CAPITAL LETTER D WITH STROKE
\SE@MapDeclare{cp852}{D2}{010E}% LATIN CAPITAL LETTER D WITH CARON
\SE@MapDeclare{cp852}{D3}{00CB}% LATIN CAPITAL LETTER E WITH DIAERESIS
\SE@MapDeclare{cp852}{D4}{010F}% LATIN SMALL LETTER D WITH CARON
\SE@MapDeclare{cp852}{D5}{0147}% LATIN CAPITAL LETTER N WITH CARON
\SE@MapDeclare{cp852}{D6}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{cp852}{D7}{00CE}% LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{cp852}{D8}{011B}% LATIN SMALL LETTER E WITH CARON
\SE@MapDeclare{cp852}{D9}{2518}% BOX DRAWINGS LIGHT UP AND LEFT
\SE@MapDeclare{cp852}{DA}{250C}% BOX DRAWINGS LIGHT DOWN AND RIGHT
\SE@MapDeclare{cp852}{DB}{2588}% FULL BLOCK
\SE@MapDeclare{cp852}{DC}{2584}% LOWER HALF BLOCK
\SE@MapDeclare{cp852}{DD}{0162}% LATIN CAPITAL LETTER T WITH CEDILLA
\SE@MapDeclare{cp852}{DE}{016E}% LATIN CAPITAL LETTER U WITH RING ABOVE
\SE@MapDeclare{cp852}{DF}{2580}% UPPER HALF BLOCK
\SE@MapDeclare{cp852}{E0}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{cp852}{E1}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{cp852}{E2}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{cp852}{E3}{0143}% LATIN CAPITAL LETTER N WITH ACUTE
\SE@MapDeclare{cp852}{E4}{0144}% LATIN SMALL LETTER N WITH ACUTE
\SE@MapDeclare{cp852}{E5}{0148}% LATIN SMALL LETTER N WITH CARON
\SE@MapDeclare{cp852}{E6}{0160}% LATIN CAPITAL LETTER S WITH CARON
\SE@MapDeclare{cp852}{E7}{0161}% LATIN SMALL LETTER S WITH CARON
\SE@MapDeclare{cp852}{E8}{0154}% LATIN CAPITAL LETTER R WITH ACUTE
\SE@MapDeclare{cp852}{E9}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{cp852}{EA}{0155}% LATIN SMALL LETTER R WITH ACUTE
\SE@MapDeclare{cp852}{EB}{0170}% LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
\SE@MapDeclare{cp852}{EC}{00FD}% LATIN SMALL LETTER Y WITH ACUTE
\SE@MapDeclare{cp852}{ED}{00DD}% LATIN CAPITAL LETTER Y WITH ACUTE
\SE@MapDeclare{cp852}{EE}{0163}% LATIN SMALL LETTER T WITH CEDILLA
\SE@MapDeclare{cp852}{EF}{00B4}% ACUTE ACCENT
\SE@MapDeclare{cp852}{F0}{00AD}% SOFT HYPHEN
\SE@MapDeclare{cp852}{F1}{02DD}% DOUBLE ACUTE ACCENT
\SE@MapDeclare{cp852}{F2}{02DB}% OGONEK
\SE@MapDeclare{cp852}{F3}{02C7}% CARON
\SE@MapDeclare{cp852}{F4}{02D8}% BREVE
\SE@MapDeclare{cp852}{F5}{00A7}% SECTION SIGN
\SE@MapDeclare{cp852}{F6}{00F7}% DIVISION SIGN
\SE@MapDeclare{cp852}{F7}{00B8}% CEDILLA
\SE@MapDeclare{cp852}{F8}{00B0}% DEGREE SIGN
\SE@MapDeclare{cp852}{F9}{00A8}% DIAERESIS
\SE@MapDeclare{cp852}{FA}{02D9}% DOT ABOVE
\SE@MapDeclare{cp852}{FB}{0171}% LATIN SMALL LETTER U WITH DOUBLE ACUTE
\SE@MapDeclare{cp852}{FC}{0158}% LATIN CAPITAL LETTER R WITH CARON
\SE@MapDeclare{cp852}{FD}{0159}% LATIN SMALL LETTER R WITH CARON
\SE@MapDeclare{cp852}{FE}{25A0}% BLACK SQUARE
\SE@MapDeclare{cp852}{FF}{00A0}% NO-BREAK SPACE
\endinput
%%
%% End of file `se-cp852.def'.
