%%
%% This is file `se-iso-8859-8.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,iso-8859-8')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-iso-8859-8.def}[2019/11/29 v1.12 stringenc: ISO-8859-8]
\def\SE@this{iso-8859-8}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{iso-8859-8}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{iso-8859-8}{A2}{00A2}% CENT SIGN
\SE@MapDeclare{iso-8859-8}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{iso-8859-8}{A4}{00A4}% CURRENCY SIGN
\SE@MapDeclare{iso-8859-8}{A5}{00A5}% YEN SIGN
\SE@MapDeclare{iso-8859-8}{A6}{00A6}% BROKEN BAR
\SE@MapDeclare{iso-8859-8}{A7}{00A7}% SECTION SIGN
\SE@MapDeclare{iso-8859-8}{A8}{00A8}% DIAERESIS
\SE@MapDeclare{iso-8859-8}{A9}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{iso-8859-8}{AA}{00D7}% MULTIPLICATION SIGN
\SE@MapDeclare{iso-8859-8}{AB}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{iso-8859-8}{AC}{00AC}% NOT SIGN
\SE@MapDeclare{iso-8859-8}{AD}{00AD}% SOFT HYPHEN
\SE@MapDeclare{iso-8859-8}{AE}{00AE}% REGISTERED SIGN
\SE@MapDeclare{iso-8859-8}{AF}{00AF}% MACRON
\SE@MapDeclare{iso-8859-8}{B0}{00B0}% DEGREE SIGN
\SE@MapDeclare{iso-8859-8}{B1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{iso-8859-8}{B2}{00B2}% SUPERSCRIPT TWO
\SE@MapDeclare{iso-8859-8}{B3}{00B3}% SUPERSCRIPT THREE
\SE@MapDeclare{iso-8859-8}{B4}{00B4}% ACUTE ACCENT
\SE@MapDeclare{iso-8859-8}{B5}{00B5}% MICRO SIGN
\SE@MapDeclare{iso-8859-8}{B6}{00B6}% PILCROW SIGN
\SE@MapDeclare{iso-8859-8}{B7}{00B7}% MIDDLE DOT
\SE@MapDeclare{iso-8859-8}{B8}{00B8}% CEDILLA
\SE@MapDeclare{iso-8859-8}{B9}{00B9}% SUPERSCRIPT ONE
\SE@MapDeclare{iso-8859-8}{BA}{00F7}% DIVISION SIGN
\SE@MapDeclare{iso-8859-8}{BB}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{iso-8859-8}{BC}{00BC}% VULGAR FRACTION ONE QUARTER
\SE@MapDeclare{iso-8859-8}{BD}{00BD}% VULGAR FRACTION ONE HALF
\SE@MapDeclare{iso-8859-8}{BE}{00BE}% VULGAR FRACTION THREE QUARTERS
\SE@MapDeclare{iso-8859-8}{DF}{2017}% DOUBLE LOW LINE
\SE@MapDeclare{iso-8859-8}{E0}{05D0}% HEBREW LETTER ALEF
\SE@MapDeclare{iso-8859-8}{E1}{05D1}% HEBREW LETTER BET
\SE@MapDeclare{iso-8859-8}{E2}{05D2}% HEBREW LETTER GIMEL
\SE@MapDeclare{iso-8859-8}{E3}{05D3}% HEBREW LETTER DALET
\SE@MapDeclare{iso-8859-8}{E4}{05D4}% HEBREW LETTER HE
\SE@MapDeclare{iso-8859-8}{E5}{05D5}% HEBREW LETTER VAV
\SE@MapDeclare{iso-8859-8}{E6}{05D6}% HEBREW LETTER ZAYIN
\SE@MapDeclare{iso-8859-8}{E7}{05D7}% HEBREW LETTER HET
\SE@MapDeclare{iso-8859-8}{E8}{05D8}% HEBREW LETTER TET
\SE@MapDeclare{iso-8859-8}{E9}{05D9}% HEBREW LETTER YOD
\SE@MapDeclare{iso-8859-8}{EA}{05DA}% HEBREW LETTER FINAL KAF
\SE@MapDeclare{iso-8859-8}{EB}{05DB}% HEBREW LETTER KAF
\SE@MapDeclare{iso-8859-8}{EC}{05DC}% HEBREW LETTER LAMED
\SE@MapDeclare{iso-8859-8}{ED}{05DD}% HEBREW LETTER FINAL MEM
\SE@MapDeclare{iso-8859-8}{EE}{05DE}% HEBREW LETTER MEM
\SE@MapDeclare{iso-8859-8}{EF}{05DF}% HEBREW LETTER FINAL NUN
\SE@MapDeclare{iso-8859-8}{F0}{05E0}% HEBREW LETTER NUN
\SE@MapDeclare{iso-8859-8}{F1}{05E1}% HEBREW LETTER SAMEKH
\SE@MapDeclare{iso-8859-8}{F2}{05E2}% HEBREW LETTER AYIN
\SE@MapDeclare{iso-8859-8}{F3}{05E3}% HEBREW LETTER FINAL PE
\SE@MapDeclare{iso-8859-8}{F4}{05E4}% HEBREW LETTER PE
\SE@MapDeclare{iso-8859-8}{F5}{05E5}% HEBREW LETTER FINAL TSADI
\SE@MapDeclare{iso-8859-8}{F6}{05E6}% HEBREW LETTER TSADI
\SE@MapDeclare{iso-8859-8}{F7}{05E7}% HEBREW LETTER QOF
\SE@MapDeclare{iso-8859-8}{F8}{05E8}% HEBREW LETTER RESH
\SE@MapDeclare{iso-8859-8}{F9}{05E9}% HEBREW LETTER SHIN
\SE@MapDeclare{iso-8859-8}{FA}{05EA}% HEBREW LETTER TAV
\SE@MapDeclare{iso-8859-8}{FD}{200E}% LEFT-TO-RIGHT MARK
\SE@MapDeclare{iso-8859-8}{FE}{200F}% RIGHT-TO-LEFT MARK
\endinput
%%
%% End of file `se-iso-8859-8.def'.
