%%
%% This is file `se-pdfdoc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `pdfdoc')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-pdfdoc.def}[2019/11/29 v1.12 stringenc: PDFDocEncoding]
\expandafter\gdef\csname\SE@PrefixTo pdfdoc\endcsname#1#2#3#4{%
  \ifcase\ifnum"#1#2#3#4<256 %
           \ifnum"#1#2#3#4>160 %
             \ltx@zero
           \else
             \ifnum"#1#2#3#4<127 %
               \ifnum"#1#2#3#4>31 %
                \ltx@zero
               \else
                 \ltx@one
               \fi
             \else
               \ltx@one
             \fi
           \fi
         \else
           \ltx@one
         \fi
    \SE@ResultAdd{#3#4}%
  \else
    \SE@MapConvertTo{pdfdoc}{#1#2#3#4}%
  \fi
}
\expandafter\gdef\csname\SE@PrefixSurrogateTo pdfdoc\endcsname
    #1#2#3#4#5#6#7#8{%
  \SE@InvalidCharacter
}
\expandafter\gdef\csname\SE@PrefixFrom pdfdoc\endcsname#1{%
  \let\SE@next\SE@pdfdoc@from
  \expandafter\SE@pdfdoc@from#1\relax\relax
}
\gdef\SE@pdfdoc@from#1#2{%
  \ifx#1\relax
    \let\SE@next\relax
  \else
    \ifcase\ifnum"#1#2>160 %
             \ifnum"#1#2="AD %
               2 %
             \else
               \ltx@zero
             \fi
           \else
             \ifnum"#1#2<127 %
               \ifnum"#1#2>31 %
                 \ltx@zero
               \else
                 \ltx@one
               \fi
             \else
               \ltx@one
             \fi
           \fi
      \SE@ResultAdd{00#1#2}%
    \or
      \SE@MapConvertFrom{pdfdoc}{#1#2}%
    \else
      \SE@InvalidCharacter
      \ifSE@TestMode
        \let\SE@next\SE@SkipRemaining
      \fi
    \fi
  \fi
  \SE@next
}
\SE@MapDeclare{pdfdoc}{09}{0009}
\SE@MapDeclare{pdfdoc}{0A}{000A}
\SE@MapDeclare{pdfdoc}{0D}{000D}
\SE@MapDeclare{pdfdoc}{18}{02D8}
\SE@MapDeclare{pdfdoc}{19}{02C7}
\SE@MapDeclare{pdfdoc}{1A}{02C6}
\SE@MapDeclare{pdfdoc}{1B}{02D9}
\SE@MapDeclare{pdfdoc}{1C}{02DD}
\SE@MapDeclare{pdfdoc}{1D}{02DB}
\SE@MapDeclare{pdfdoc}{1E}{02DA}
\SE@MapDeclare{pdfdoc}{1F}{02DC}
\SE@MapDeclare{pdfdoc}{80}{2022}
\SE@MapDeclare{pdfdoc}{81}{2020}
\SE@MapDeclare{pdfdoc}{82}{2021}
\SE@MapDeclare{pdfdoc}{83}{2026}
\SE@MapDeclare{pdfdoc}{84}{2014}
\SE@MapDeclare{pdfdoc}{85}{2013}
\SE@MapDeclare{pdfdoc}{86}{0192}
\SE@MapDeclare{pdfdoc}{87}{2044}
\SE@MapDeclare{pdfdoc}{88}{2039}
\SE@MapDeclare{pdfdoc}{89}{203A}
\SE@MapDeclare{pdfdoc}{8A}{2212}
\SE@MapDeclare{pdfdoc}{8B}{2030}
\SE@MapDeclare{pdfdoc}{8C}{201E}
\SE@MapDeclare{pdfdoc}{8D}{201C}
\SE@MapDeclare{pdfdoc}{8E}{201D}
\SE@MapDeclare{pdfdoc}{8F}{2018}
\SE@MapDeclare{pdfdoc}{90}{2019}
\SE@MapDeclare{pdfdoc}{91}{201A}
\SE@MapDeclare{pdfdoc}{92}{2122}
\SE@MapDeclare{pdfdoc}{93}{FB01}
\SE@MapDeclare{pdfdoc}{94}{FB02}
\SE@MapDeclare{pdfdoc}{95}{0141}
\SE@MapDeclare{pdfdoc}{96}{0152}
\SE@MapDeclare{pdfdoc}{97}{0160}
\SE@MapDeclare{pdfdoc}{98}{0178}
\SE@MapDeclare{pdfdoc}{99}{017D}
\SE@MapDeclare{pdfdoc}{9A}{0131}
\SE@MapDeclare{pdfdoc}{9B}{0142}
\SE@MapDeclare{pdfdoc}{9C}{0153}
\SE@MapDeclare{pdfdoc}{9D}{0161}
\SE@MapDeclare{pdfdoc}{9E}{017E}
\SE@MapDeclare{pdfdoc}{A0}{20AC}
\endinput
%%
%% End of file `se-pdfdoc.def'.
