%%
%% This is file `se-mac-roman.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,mac-roman')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-mac-roman.def}[2019/11/29 v1.12 stringenc: Mac OS Roman]
\def\SE@this{mac-roman}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{mac-roman}{80}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{mac-roman}{81}{00C5}% LATIN CAPITAL LETTER A WITH RING ABOVE
\SE@MapDeclare{mac-roman}{82}{00C7}% LATIN CAPITAL LETTER C WITH CEDILLA
\SE@MapDeclare{mac-roman}{83}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{mac-roman}{84}{00D1}% LATIN CAPITAL LETTER N WITH TILDE
\SE@MapDeclare{mac-roman}{85}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{mac-roman}{86}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{mac-roman}{87}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{mac-roman}{88}{00E0}% LATIN SMALL LETTER A WITH GRAVE
\SE@MapDeclare{mac-roman}{89}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{8A}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{mac-roman}{8B}{00E3}% LATIN SMALL LETTER A WITH TILDE
\SE@MapDeclare{mac-roman}{8C}{00E5}% LATIN SMALL LETTER A WITH RING ABOVE
\SE@MapDeclare{mac-roman}{8D}{00E7}% LATIN SMALL LETTER C WITH CEDILLA
\SE@MapDeclare{mac-roman}{8E}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{mac-roman}{8F}{00E8}% LATIN SMALL LETTER E WITH GRAVE
\SE@MapDeclare{mac-roman}{90}{00EA}% LATIN SMALL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{91}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{mac-roman}{92}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{mac-roman}{93}{00EC}% LATIN SMALL LETTER I WITH GRAVE
\SE@MapDeclare{mac-roman}{94}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{95}{00EF}% LATIN SMALL LETTER I WITH DIAERESIS
\SE@MapDeclare{mac-roman}{96}{00F1}% LATIN SMALL LETTER N WITH TILDE
\SE@MapDeclare{mac-roman}{97}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{mac-roman}{98}{00F2}% LATIN SMALL LETTER O WITH GRAVE
\SE@MapDeclare{mac-roman}{99}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{9A}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{mac-roman}{9B}{00F5}% LATIN SMALL LETTER O WITH TILDE
\SE@MapDeclare{mac-roman}{9C}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{mac-roman}{9D}{00F9}% LATIN SMALL LETTER U WITH GRAVE
\SE@MapDeclare{mac-roman}{9E}{00FB}% LATIN SMALL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{9F}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{mac-roman}{A0}{2020}% DAGGER
\SE@MapDeclare{mac-roman}{A1}{00B0}% DEGREE SIGN
\SE@MapDeclare{mac-roman}{A2}{00A2}% CENT SIGN
\SE@MapDeclare{mac-roman}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{mac-roman}{A4}{00A7}% SECTION SIGN
\SE@MapDeclare{mac-roman}{A5}{2022}% BULLET
\SE@MapDeclare{mac-roman}{A6}{00B6}% PILCROW SIGN
\SE@MapDeclare{mac-roman}{A7}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{mac-roman}{A8}{00AE}% REGISTERED SIGN
\SE@MapDeclare{mac-roman}{A9}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{mac-roman}{AA}{2122}% TRADE MARK SIGN
\SE@MapDeclare{mac-roman}{AB}{00B4}% ACUTE ACCENT
\SE@MapDeclare{mac-roman}{AC}{00A8}% DIAERESIS
\SE@MapDeclare{mac-roman}{AD}{2260}% NOT EQUAL TO
\SE@MapDeclare{mac-roman}{AE}{00C6}% LATIN CAPITAL LETTER AE
\SE@MapDeclare{mac-roman}{AF}{00D8}% LATIN CAPITAL LETTER O WITH STROKE
\SE@MapDeclare{mac-roman}{B0}{221E}% INFINITY
\SE@MapDeclare{mac-roman}{B1}{00B1}% PLUS-MINUS SIGN
\SE@MapDeclare{mac-roman}{B2}{2264}% LESS-THAN OR EQUAL TO
\SE@MapDeclare{mac-roman}{B3}{2265}% GREATER-THAN OR EQUAL TO
\SE@MapDeclare{mac-roman}{B4}{00A5}% YEN SIGN
\SE@MapDeclare{mac-roman}{B5}{00B5}% MICRO SIGN
\SE@MapDeclare{mac-roman}{B6}{2202}% PARTIAL DIFFERENTIAL
\SE@MapDeclare{mac-roman}{B7}{2211}% N-ARY SUMMATION
\SE@MapDeclare{mac-roman}{B8}{220F}% N-ARY PRODUCT
\SE@MapDeclare{mac-roman}{B9}{03C0}% GREEK SMALL LETTER PI
\SE@MapDeclare{mac-roman}{BA}{222B}% INTEGRAL
\SE@MapDeclare{mac-roman}{BB}{00AA}% FEMININE ORDINAL INDICATOR
\SE@MapDeclare{mac-roman}{BC}{00BA}% MASCULINE ORDINAL INDICATOR
\SE@MapDeclare{mac-roman}{BD}{03A9}% GREEK CAPITAL LETTER OMEGA
\SE@MapDeclare{mac-roman}{BE}{00E6}% LATIN SMALL LETTER AE
\SE@MapDeclare{mac-roman}{BF}{00F8}% LATIN SMALL LETTER O WITH STROKE
\SE@MapDeclare{mac-roman}{C0}{00BF}% INVERTED QUESTION MARK
\SE@MapDeclare{mac-roman}{C1}{00A1}% INVERTED EXCLAMATION MARK
\SE@MapDeclare{mac-roman}{C2}{00AC}% NOT SIGN
\SE@MapDeclare{mac-roman}{C3}{221A}% SQUARE ROOT
\SE@MapDeclare{mac-roman}{C4}{0192}% LATIN SMALL LETTER F WITH HOOK
\SE@MapDeclare{mac-roman}{C5}{2248}% ALMOST EQUAL TO
\SE@MapDeclare{mac-roman}{C6}{2206}% INCREMENT
\SE@MapDeclare{mac-roman}{C7}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{mac-roman}{C8}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{mac-roman}{C9}{2026}% HORIZONTAL ELLIPSIS
\SE@MapDeclare{mac-roman}{CA}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{mac-roman}{CB}{00C0}% LATIN CAPITAL LETTER A WITH GRAVE
\SE@MapDeclare{mac-roman}{CC}{00C3}% LATIN CAPITAL LETTER A WITH TILDE
\SE@MapDeclare{mac-roman}{CD}{00D5}% LATIN CAPITAL LETTER O WITH TILDE
\SE@MapDeclare{mac-roman}{CE}{0152}% LATIN CAPITAL LIGATURE OE
\SE@MapDeclare{mac-roman}{CF}{0153}% LATIN SMALL LIGATURE OE
\SE@MapDeclare{mac-roman}{D0}{2013}% EN DASH
\SE@MapDeclare{mac-roman}{D1}{2014}% EM DASH
\SE@MapDeclare{mac-roman}{D2}{201C}% LEFT DOUBLE QUOTATION MARK
\SE@MapDeclare{mac-roman}{D3}{201D}% RIGHT DOUBLE QUOTATION MARK
\SE@MapDeclare{mac-roman}{D4}{2018}% LEFT SINGLE QUOTATION MARK
\SE@MapDeclare{mac-roman}{D5}{2019}% RIGHT SINGLE QUOTATION MARK
\SE@MapDeclare{mac-roman}{D6}{00F7}% DIVISION SIGN
\SE@MapDeclare{mac-roman}{D7}{25CA}% LOZENGE
\SE@MapDeclare{mac-roman}{D8}{00FF}% LATIN SMALL LETTER Y WITH DIAERESIS
\SE@MapDeclare{mac-roman}{D9}{0178}% LATIN CAPITAL LETTER Y WITH DIAERESIS
\SE@MapDeclare{mac-roman}{DA}{2044}% FRACTION SLASH
\SE@MapDeclare{mac-roman}{DB}{20AC}% EURO SIGN
\SE@MapDeclare{mac-roman}{DC}{2039}% SINGLE LEFT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{mac-roman}{DD}{203A}% SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{mac-roman}{DE}{FB01}% LATIN SMALL LIGATURE FI
\SE@MapDeclare{mac-roman}{DF}{FB02}% LATIN SMALL LIGATURE FL
\SE@MapDeclare{mac-roman}{E0}{2021}% DOUBLE DAGGER
\SE@MapDeclare{mac-roman}{E1}{00B7}% MIDDLE DOT
\SE@MapDeclare{mac-roman}{E2}{201A}% SINGLE LOW-9 QUOTATION MARK
\SE@MapDeclare{mac-roman}{E3}{201E}% DOUBLE LOW-9 QUOTATION MARK
\SE@MapDeclare{mac-roman}{E4}{2030}% PER MILLE SIGN
\SE@MapDeclare{mac-roman}{E5}{00C2}% LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{E6}{00CA}% LATIN CAPITAL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{E7}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{mac-roman}{E8}{00CB}% LATIN CAPITAL LETTER E WITH DIAERESIS
\SE@MapDeclare{mac-roman}{E9}{00C8}% LATIN CAPITAL LETTER E WITH GRAVE
\SE@MapDeclare{mac-roman}{EA}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{mac-roman}{EB}{00CE}% LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{EC}{00CF}% LATIN CAPITAL LETTER I WITH DIAERESIS
\SE@MapDeclare{mac-roman}{ED}{00CC}% LATIN CAPITAL LETTER I WITH GRAVE
\SE@MapDeclare{mac-roman}{EE}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{mac-roman}{EF}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{F0}{F8FF}% Apple logo
\SE@MapDeclare{mac-roman}{F1}{00D2}% LATIN CAPITAL LETTER O WITH GRAVE
\SE@MapDeclare{mac-roman}{F2}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{mac-roman}{F3}{00DB}% LATIN CAPITAL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{mac-roman}{F4}{00D9}% LATIN CAPITAL LETTER U WITH GRAVE
\SE@MapDeclare{mac-roman}{F5}{0131}% LATIN SMALL LETTER DOTLESS I
\SE@MapDeclare{mac-roman}{F6}{02C6}% MODIFIER LETTER CIRCUMFLEX ACCENT
\SE@MapDeclare{mac-roman}{F7}{02DC}% SMALL TILDE
\SE@MapDeclare{mac-roman}{F8}{00AF}% MACRON
\SE@MapDeclare{mac-roman}{F9}{02D8}% BREVE
\SE@MapDeclare{mac-roman}{FA}{02D9}% DOT ABOVE
\SE@MapDeclare{mac-roman}{FB}{02DA}% RING ABOVE
\SE@MapDeclare{mac-roman}{FC}{00B8}% CEDILLA
\SE@MapDeclare{mac-roman}{FD}{02DD}% DOUBLE ACUTE ACCENT
\SE@MapDeclare{mac-roman}{FE}{02DB}% OGONEK
\SE@MapDeclare{mac-roman}{FF}{02C7}% CARON
\endinput
%%
%% End of file `se-mac-roman.def'.
