%%
%% This is file `se-iso-8859-4.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,iso-8859-4')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-iso-8859-4.def}[2019/11/29 v1.12 stringenc: ISO-8859-4]
\def\SE@this{iso-8859-4}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{iso-8859-4}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{iso-8859-4}{A1}{0104}% LATIN CAPITAL LETTER A WITH OGONEK
\SE@MapDeclare{iso-8859-4}{A2}{0138}% LATIN SMALL LETTER KRA
\SE@MapDeclare{iso-8859-4}{A3}{0156}% LATIN CAPITAL LETTER R WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{A4}{00A4}% CURRENCY SIGN
\SE@MapDeclare{iso-8859-4}{A5}{0128}% LATIN CAPITAL LETTER I WITH TILDE
\SE@MapDeclare{iso-8859-4}{A6}{013B}% LATIN CAPITAL LETTER L WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{A7}{00A7}% SECTION SIGN
\SE@MapDeclare{iso-8859-4}{A8}{00A8}% DIAERESIS
\SE@MapDeclare{iso-8859-4}{A9}{0160}% LATIN CAPITAL LETTER S WITH CARON
\SE@MapDeclare{iso-8859-4}{AA}{0112}% LATIN CAPITAL LETTER E WITH MACRON
\SE@MapDeclare{iso-8859-4}{AB}{0122}% LATIN CAPITAL LETTER G WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{AC}{0166}% LATIN CAPITAL LETTER T WITH STROKE
\SE@MapDeclare{iso-8859-4}{AD}{00AD}% SOFT HYPHEN
\SE@MapDeclare{iso-8859-4}{AE}{017D}% LATIN CAPITAL LETTER Z WITH CARON
\SE@MapDeclare{iso-8859-4}{AF}{00AF}% MACRON
\SE@MapDeclare{iso-8859-4}{B0}{00B0}% DEGREE SIGN
\SE@MapDeclare{iso-8859-4}{B1}{0105}% LATIN SMALL LETTER A WITH OGONEK
\SE@MapDeclare{iso-8859-4}{B2}{02DB}% OGONEK
\SE@MapDeclare{iso-8859-4}{B3}{0157}% LATIN SMALL LETTER R WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{B4}{00B4}% ACUTE ACCENT
\SE@MapDeclare{iso-8859-4}{B5}{0129}% LATIN SMALL LETTER I WITH TILDE
\SE@MapDeclare{iso-8859-4}{B6}{013C}% LATIN SMALL LETTER L WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{B7}{02C7}% CARON
\SE@MapDeclare{iso-8859-4}{B8}{00B8}% CEDILLA
\SE@MapDeclare{iso-8859-4}{B9}{0161}% LATIN SMALL LETTER S WITH CARON
\SE@MapDeclare{iso-8859-4}{BA}{0113}% LATIN SMALL LETTER E WITH MACRON
\SE@MapDeclare{iso-8859-4}{BB}{0123}% LATIN SMALL LETTER G WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{BC}{0167}% LATIN SMALL LETTER T WITH STROKE
\SE@MapDeclare{iso-8859-4}{BD}{014A}% LATIN CAPITAL LETTER ENG
\SE@MapDeclare{iso-8859-4}{BE}{017E}% LATIN SMALL LETTER Z WITH CARON
\SE@MapDeclare{iso-8859-4}{BF}{014B}% LATIN SMALL LETTER ENG
\SE@MapDeclare{iso-8859-4}{C0}{0100}% LATIN CAPITAL LETTER A WITH MACRON
\SE@MapDeclare{iso-8859-4}{C1}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{iso-8859-4}{C2}{00C2}% LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-4}{C3}{00C3}% LATIN CAPITAL LETTER A WITH TILDE
\SE@MapDeclare{iso-8859-4}{C4}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{iso-8859-4}{C5}{00C5}% LATIN CAPITAL LETTER A WITH RING ABOVE
\SE@MapDeclare{iso-8859-4}{C6}{00C6}% LATIN CAPITAL LETTER AE
\SE@MapDeclare{iso-8859-4}{C7}{012E}% LATIN CAPITAL LETTER I WITH OGONEK
\SE@MapDeclare{iso-8859-4}{C8}{010C}% LATIN CAPITAL LETTER C WITH CARON
\SE@MapDeclare{iso-8859-4}{C9}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{iso-8859-4}{CA}{0118}% LATIN CAPITAL LETTER E WITH OGONEK
\SE@MapDeclare{iso-8859-4}{CB}{00CB}% LATIN CAPITAL LETTER E WITH DIAERESIS
\SE@MapDeclare{iso-8859-4}{CC}{0116}% LATIN CAPITAL LETTER E WITH DOT ABOVE
\SE@MapDeclare{iso-8859-4}{CD}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{iso-8859-4}{CE}{00CE}% LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-4}{CF}{012A}% LATIN CAPITAL LETTER I WITH MACRON
\SE@MapDeclare{iso-8859-4}{D0}{0110}% LATIN CAPITAL LETTER D WITH STROKE
\SE@MapDeclare{iso-8859-4}{D1}{0145}% LATIN CAPITAL LETTER N WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{D2}{014C}% LATIN CAPITAL LETTER O WITH MACRON
\SE@MapDeclare{iso-8859-4}{D3}{0136}% LATIN CAPITAL LETTER K WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{D4}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-4}{D5}{00D5}% LATIN CAPITAL LETTER O WITH TILDE
\SE@MapDeclare{iso-8859-4}{D6}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{iso-8859-4}{D7}{00D7}% MULTIPLICATION SIGN
\SE@MapDeclare{iso-8859-4}{D8}{00D8}% LATIN CAPITAL LETTER O WITH STROKE
\SE@MapDeclare{iso-8859-4}{D9}{0172}% LATIN CAPITAL LETTER U WITH OGONEK
\SE@MapDeclare{iso-8859-4}{DA}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{iso-8859-4}{DB}{00DB}% LATIN CAPITAL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-4}{DC}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{iso-8859-4}{DD}{0168}% LATIN CAPITAL LETTER U WITH TILDE
\SE@MapDeclare{iso-8859-4}{DE}{016A}% LATIN CAPITAL LETTER U WITH MACRON
\SE@MapDeclare{iso-8859-4}{DF}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{iso-8859-4}{E0}{0101}% LATIN SMALL LETTER A WITH MACRON
\SE@MapDeclare{iso-8859-4}{E1}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{iso-8859-4}{E2}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-4}{E3}{00E3}% LATIN SMALL LETTER A WITH TILDE
\SE@MapDeclare{iso-8859-4}{E4}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{iso-8859-4}{E5}{00E5}% LATIN SMALL LETTER A WITH RING ABOVE
\SE@MapDeclare{iso-8859-4}{E6}{00E6}% LATIN SMALL LETTER AE
\SE@MapDeclare{iso-8859-4}{E7}{012F}% LATIN SMALL LETTER I WITH OGONEK
\SE@MapDeclare{iso-8859-4}{E8}{010D}% LATIN SMALL LETTER C WITH CARON
\SE@MapDeclare{iso-8859-4}{E9}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{iso-8859-4}{EA}{0119}% LATIN SMALL LETTER E WITH OGONEK
\SE@MapDeclare{iso-8859-4}{EB}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{iso-8859-4}{EC}{0117}% LATIN SMALL LETTER E WITH DOT ABOVE
\SE@MapDeclare{iso-8859-4}{ED}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{iso-8859-4}{EE}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-4}{EF}{012B}% LATIN SMALL LETTER I WITH MACRON
\SE@MapDeclare{iso-8859-4}{F0}{0111}% LATIN SMALL LETTER D WITH STROKE
\SE@MapDeclare{iso-8859-4}{F1}{0146}% LATIN SMALL LETTER N WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{F2}{014D}% LATIN SMALL LETTER O WITH MACRON
\SE@MapDeclare{iso-8859-4}{F3}{0137}% LATIN SMALL LETTER K WITH CEDILLA
\SE@MapDeclare{iso-8859-4}{F4}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-4}{F5}{00F5}% LATIN SMALL LETTER O WITH TILDE
\SE@MapDeclare{iso-8859-4}{F6}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{iso-8859-4}{F7}{00F7}% DIVISION SIGN
\SE@MapDeclare{iso-8859-4}{F8}{00F8}% LATIN SMALL LETTER O WITH STROKE
\SE@MapDeclare{iso-8859-4}{F9}{0173}% LATIN SMALL LETTER U WITH OGONEK
\SE@MapDeclare{iso-8859-4}{FA}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{iso-8859-4}{FB}{00FB}% LATIN SMALL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-4}{FC}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{iso-8859-4}{FD}{0169}% LATIN SMALL LETTER U WITH TILDE
\SE@MapDeclare{iso-8859-4}{FE}{016B}% LATIN SMALL LETTER U WITH MACRON
\SE@MapDeclare{iso-8859-4}{FF}{02D9}% DOT ABOVE
\endinput
%%
%% End of file `se-iso-8859-4.def'.
