%%
%% This is file `se-mac-centeuro.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,mac-centeuro')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-mac-centeuro.def}[2019/11/29 v1.12 stringenc: Mac OS Central European]
\def\SE@this{mac-centeuro}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{mac-centeuro}{80}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{mac-centeuro}{81}{0100}% LATIN CAPITAL LETTER A WITH MACRON
\SE@MapDeclare{mac-centeuro}{82}{0101}% LATIN SMALL LETTER A WITH MACRON
\SE@MapDeclare{mac-centeuro}{83}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{mac-centeuro}{84}{0104}% LATIN CAPITAL LETTER A WITH OGONEK
\SE@MapDeclare{mac-centeuro}{85}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{mac-centeuro}{86}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{mac-centeuro}{87}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{mac-centeuro}{88}{0105}% LATIN SMALL LETTER A WITH OGONEK
\SE@MapDeclare{mac-centeuro}{89}{010C}% LATIN CAPITAL LETTER C WITH CARON
\SE@MapDeclare{mac-centeuro}{8A}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{mac-centeuro}{8B}{010D}% LATIN SMALL LETTER C WITH CARON
\SE@MapDeclare{mac-centeuro}{8C}{0106}% LATIN CAPITAL LETTER C WITH ACUTE
\SE@MapDeclare{mac-centeuro}{8D}{0107}% LATIN SMALL LETTER C WITH ACUTE
\SE@MapDeclare{mac-centeuro}{8E}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{mac-centeuro}{8F}{0179}% LATIN CAPITAL LETTER Z WITH ACUTE
\SE@MapDeclare{mac-centeuro}{90}{017A}% LATIN SMALL LETTER Z WITH ACUTE
\SE@MapDeclare{mac-centeuro}{91}{010E}% LATIN CAPITAL LETTER D WITH CARON
\SE@MapDeclare{mac-centeuro}{92}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{mac-centeuro}{93}{010F}% LATIN SMALL LETTER D WITH CARON
\SE@MapDeclare{mac-centeuro}{94}{0112}% LATIN CAPITAL LETTER E WITH MACRON
\SE@MapDeclare{mac-centeuro}{95}{0113}% LATIN SMALL LETTER E WITH MACRON
\SE@MapDeclare{mac-centeuro}{96}{0116}% LATIN CAPITAL LETTER E WITH DOT ABOVE
\SE@MapDeclare{mac-centeuro}{97}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{mac-centeuro}{98}{0117}% LATIN SMALL LETTER E WITH DOT ABOVE
\SE@MapDeclare{mac-centeuro}{99}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{mac-centeuro}{9A}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{mac-centeuro}{9B}{00F5}% LATIN SMALL LETTER O WITH TILDE
\SE@MapDeclare{mac-centeuro}{9C}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{mac-centeuro}{9D}{011A}% LATIN CAPITAL LETTER E WITH CARON
\SE@MapDeclare{mac-centeuro}{9E}{011B}% LATIN SMALL LETTER E WITH CARON
\SE@MapDeclare{mac-centeuro}{9F}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{mac-centeuro}{A0}{2020}% DAGGER
\SE@MapDeclare{mac-centeuro}{A1}{00B0}% DEGREE SIGN
\SE@MapDeclare{mac-centeuro}{A2}{0118}% LATIN CAPITAL LETTER E WITH OGONEK
\SE@MapDeclare{mac-centeuro}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{mac-centeuro}{A4}{00A7}% SECTION SIGN
\SE@MapDeclare{mac-centeuro}{A5}{2022}% BULLET
\SE@MapDeclare{mac-centeuro}{A6}{00B6}% PILCROW SIGN
\SE@MapDeclare{mac-centeuro}{A7}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{mac-centeuro}{A8}{00AE}% REGISTERED SIGN
\SE@MapDeclare{mac-centeuro}{A9}{00A9}% COPYRIGHT SIGN
\SE@MapDeclare{mac-centeuro}{AA}{2122}% TRADE MARK SIGN
\SE@MapDeclare{mac-centeuro}{AB}{0119}% LATIN SMALL LETTER E WITH OGONEK
\SE@MapDeclare{mac-centeuro}{AC}{00A8}% DIAERESIS
\SE@MapDeclare{mac-centeuro}{AD}{2260}% NOT EQUAL TO
\SE@MapDeclare{mac-centeuro}{AE}{0123}% LATIN SMALL LETTER G WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{AF}{012E}% LATIN CAPITAL LETTER I WITH OGONEK
\SE@MapDeclare{mac-centeuro}{B0}{012F}% LATIN SMALL LETTER I WITH OGONEK
\SE@MapDeclare{mac-centeuro}{B1}{012A}% LATIN CAPITAL LETTER I WITH MACRON
\SE@MapDeclare{mac-centeuro}{B2}{2264}% LESS-THAN OR EQUAL TO
\SE@MapDeclare{mac-centeuro}{B3}{2265}% GREATER-THAN OR EQUAL TO
\SE@MapDeclare{mac-centeuro}{B4}{012B}% LATIN SMALL LETTER I WITH MACRON
\SE@MapDeclare{mac-centeuro}{B5}{0136}% LATIN CAPITAL LETTER K WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{B6}{2202}% PARTIAL DIFFERENTIAL
\SE@MapDeclare{mac-centeuro}{B7}{2211}% N-ARY SUMMATION
\SE@MapDeclare{mac-centeuro}{B8}{0142}% LATIN SMALL LETTER L WITH STROKE
\SE@MapDeclare{mac-centeuro}{B9}{013B}% LATIN CAPITAL LETTER L WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{BA}{013C}% LATIN SMALL LETTER L WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{BB}{013D}% LATIN CAPITAL LETTER L WITH CARON
\SE@MapDeclare{mac-centeuro}{BC}{013E}% LATIN SMALL LETTER L WITH CARON
\SE@MapDeclare{mac-centeuro}{BD}{0139}% LATIN CAPITAL LETTER L WITH ACUTE
\SE@MapDeclare{mac-centeuro}{BE}{013A}% LATIN SMALL LETTER L WITH ACUTE
\SE@MapDeclare{mac-centeuro}{BF}{0145}% LATIN CAPITAL LETTER N WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{C0}{0146}% LATIN SMALL LETTER N WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{C1}{0143}% LATIN CAPITAL LETTER N WITH ACUTE
\SE@MapDeclare{mac-centeuro}{C2}{00AC}% NOT SIGN
\SE@MapDeclare{mac-centeuro}{C3}{221A}% SQUARE ROOT
\SE@MapDeclare{mac-centeuro}{C4}{0144}% LATIN SMALL LETTER N WITH ACUTE
\SE@MapDeclare{mac-centeuro}{C5}{0147}% LATIN CAPITAL LETTER N WITH CARON
\SE@MapDeclare{mac-centeuro}{C6}{2206}% INCREMENT
\SE@MapDeclare{mac-centeuro}{C7}{00AB}% LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{C8}{00BB}% RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{C9}{2026}% HORIZONTAL ELLIPSIS
\SE@MapDeclare{mac-centeuro}{CA}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{mac-centeuro}{CB}{0148}% LATIN SMALL LETTER N WITH CARON
\SE@MapDeclare{mac-centeuro}{CC}{0150}% LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
\SE@MapDeclare{mac-centeuro}{CD}{00D5}% LATIN CAPITAL LETTER O WITH TILDE
\SE@MapDeclare{mac-centeuro}{CE}{0151}% LATIN SMALL LETTER O WITH DOUBLE ACUTE
\SE@MapDeclare{mac-centeuro}{CF}{014C}% LATIN CAPITAL LETTER O WITH MACRON
\SE@MapDeclare{mac-centeuro}{D0}{2013}% EN DASH
\SE@MapDeclare{mac-centeuro}{D1}{2014}% EM DASH
\SE@MapDeclare{mac-centeuro}{D2}{201C}% LEFT DOUBLE QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{D3}{201D}% RIGHT DOUBLE QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{D4}{2018}% LEFT SINGLE QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{D5}{2019}% RIGHT SINGLE QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{D6}{00F7}% DIVISION SIGN
\SE@MapDeclare{mac-centeuro}{D7}{25CA}% LOZENGE
\SE@MapDeclare{mac-centeuro}{D8}{014D}% LATIN SMALL LETTER O WITH MACRON
\SE@MapDeclare{mac-centeuro}{D9}{0154}% LATIN CAPITAL LETTER R WITH ACUTE
\SE@MapDeclare{mac-centeuro}{DA}{0155}% LATIN SMALL LETTER R WITH ACUTE
\SE@MapDeclare{mac-centeuro}{DB}{0158}% LATIN CAPITAL LETTER R WITH CARON
\SE@MapDeclare{mac-centeuro}{DC}{2039}% SINGLE LEFT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{DD}{203A}% SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{DE}{0159}% LATIN SMALL LETTER R WITH CARON
\SE@MapDeclare{mac-centeuro}{DF}{0156}% LATIN CAPITAL LETTER R WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{E0}{0157}% LATIN SMALL LETTER R WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{E1}{0160}% LATIN CAPITAL LETTER S WITH CARON
\SE@MapDeclare{mac-centeuro}{E2}{201A}% SINGLE LOW-9 QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{E3}{201E}% DOUBLE LOW-9 QUOTATION MARK
\SE@MapDeclare{mac-centeuro}{E4}{0161}% LATIN SMALL LETTER S WITH CARON
\SE@MapDeclare{mac-centeuro}{E5}{015A}% LATIN CAPITAL LETTER S WITH ACUTE
\SE@MapDeclare{mac-centeuro}{E6}{015B}% LATIN SMALL LETTER S WITH ACUTE
\SE@MapDeclare{mac-centeuro}{E7}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{mac-centeuro}{E8}{0164}% LATIN CAPITAL LETTER T WITH CARON
\SE@MapDeclare{mac-centeuro}{E9}{0165}% LATIN SMALL LETTER T WITH CARON
\SE@MapDeclare{mac-centeuro}{EA}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{mac-centeuro}{EB}{017D}% LATIN CAPITAL LETTER Z WITH CARON
\SE@MapDeclare{mac-centeuro}{EC}{017E}% LATIN SMALL LETTER Z WITH CARON
\SE@MapDeclare{mac-centeuro}{ED}{016A}% LATIN CAPITAL LETTER U WITH MACRON
\SE@MapDeclare{mac-centeuro}{EE}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{mac-centeuro}{EF}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{mac-centeuro}{F0}{016B}% LATIN SMALL LETTER U WITH MACRON
\SE@MapDeclare{mac-centeuro}{F1}{016E}% LATIN CAPITAL LETTER U WITH RING ABOVE
\SE@MapDeclare{mac-centeuro}{F2}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{mac-centeuro}{F3}{016F}% LATIN SMALL LETTER U WITH RING ABOVE
\SE@MapDeclare{mac-centeuro}{F4}{0170}% LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
\SE@MapDeclare{mac-centeuro}{F5}{0171}% LATIN SMALL LETTER U WITH DOUBLE ACUTE
\SE@MapDeclare{mac-centeuro}{F6}{0172}% LATIN CAPITAL LETTER U WITH OGONEK
\SE@MapDeclare{mac-centeuro}{F7}{0173}% LATIN SMALL LETTER U WITH OGONEK
\SE@MapDeclare{mac-centeuro}{F8}{00DD}% LATIN CAPITAL LETTER Y WITH ACUTE
\SE@MapDeclare{mac-centeuro}{F9}{00FD}% LATIN SMALL LETTER Y WITH ACUTE
\SE@MapDeclare{mac-centeuro}{FA}{0137}% LATIN SMALL LETTER K WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{FB}{017B}% LATIN CAPITAL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{mac-centeuro}{FC}{0141}% LATIN CAPITAL LETTER L WITH STROKE
\SE@MapDeclare{mac-centeuro}{FD}{017C}% LATIN SMALL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{mac-centeuro}{FE}{0122}% LATIN CAPITAL LETTER G WITH CEDILLA
\SE@MapDeclare{mac-centeuro}{FF}{02C7}% CARON
\endinput
%%
%% End of file `se-mac-centeuro.def'.
